Index: lib/contents.html
===================================================================
--- lib/contents.html	(revision 153)
+++ lib/contents.html	(revision 154)
@@ -29,6 +29,12 @@
   Format: 
   <input type="radio" name="qformat" value="xml">XML
   <input type="radio" name="qformat" value="html" checked>HTML
+  <br />
+  Return: &nbsp;
+  <select name=doctype>
+  <option value="-//NCEAS//eml-dataset//EN">eml-dataset
+  <option value="any">Any
+  </select>
 </form>
 <a href="loadxml.html" target="right">Load an XML Document</a>
 <br /><a href="validate.html" target="right">Validate an XML Document</a>
Index: lib/metacat.jar
===================================================================
--- lib/metacat.jar	(revision 153)
+++ lib/metacat.jar	(revision 154)
@@ -1,5 +1,5 @@
-PK&�Ì(	META-INF/PKPK&�Ì(META-INF/MANIFEST.MFóMÌËLK-.Ñ
-K-*ÎÌÏ³R0Ô3àåPK©RfÍPK&�Ì(edu/PKPK&�Ì(	edu/ucsb/PKPK&�Ì(edu/ucsb/nceas/PKPK&�Ì(edu/ucsb/nceas/metacat/PKPK&�Ì()edu/ucsb/nceas/metacat/BasicElement.class�U[wUþ¦	Iš
+PKÓ¥Í(	META-INF/PKPKÓ¥Í(META-INF/MANIFEST.MFóMÌËLK-.Ñ
+K-*ÎÌÏ³R0Ô3àåPK©RfÍPKÓ¥Í(edu/PKPKÓ¥Í(	edu/ucsb/PKPKÓ¥Í(edu/ucsb/nceas/PKPKÓ¥Í(edu/ucsb/nceas/metacat/PKPKÓ¥Í()edu/ucsb/nceas/metacat/BasicElement.class�U[wUþ¦	Iš
 )-ˆM/@H)áªH)—–"­m@[©ÅL’C;�LBf-ÊÅˆúä£þ–k‰ËiUÔåòAÖòG©ß™™¦É0<dŸ½÷ùöwöÙ{çÌ?ÿþúÀç�`(‚7"˜
 #††F%ŒëaÜc!ŒÅ0nF±;£KÑ,…*ÅZ)Ö !µ]r#ÙL³_ŠÝRH±Gî¦šÅ^¶¯-Ø/µR;(!‡¤xIŠ—£á°Ü}EšG$é Š×1"ÅYïa\Å%LªÐð¶ŠÎ«Èâ3*.cXÅfUÌcLÅ5œRñ¾ô}€*nIðm\PqG‚ï"­âC¼¦â�ô}†“
 ”8=
@@ -11,24 +11,29 @@
 e6ëÊ¶´9ÃÖ"VÑ)ºùR‡DÐ$ŸajMòIµ×;®Í×Ú^ù`Ûë-w½íâø†sÝE¾õ”oÒ:ÃO”Â5ž\Fkò	ÖÎ.£­Šª*Õ
 U´'Ulþ�oQ¶3âDZÑ‹-èCmÉúªËšr³mM´c¡elLvUÑ¹J²ŽÇÇùå9A}È>ëqOcJë’ýUlOÆ«èIÆ‚UÄ½yìcûIs€4±	{¹{‘·r¨vðÖM\£ÉÇèè_Â¦™Õø¨½ó;c£GÇ„ÓçÆ¨ŒigÌ"ò}-*dWëKÊ+8éF|E¼Ìeö	šY³õÊ¤’–ÑKxñHð!uA—MJ÷n‡4Ýß¦,!F+Ö ˜é�j“TeÄ6_ÿ÷”ìX=~?çÀuŽÁ
 ^`�ßð›ˆñóÛÁ¯o/žb³�s Æé›æ‡WÁU»iÊÉä#²KØâ½Ô_”yF;èm¼”ô®!ºó‘:EYÀ±T©Aãßz ßPµRÕC»½	üDYôM Ç›ÀEÊ’/ëv/ëUÊr-×>wÞÕäìcl^ºÀÙö¦ü”ò#œs#†!‡uKÿßXoÏ;Ö7ó-?bk[p	½Þ™¼Ï™|Ày¼�
-ø�¸ÇÝ�qÚåëqùBž¿„3�³d˜¡çŒÖðÎ<†’[æßÁGü#zî!ýž�n/þgâ—é¹ïŸO�/ˆÏÒó©?ÿv/þñEzÞµ_œéÿPK°‰^"PK&�Ì()edu/ucsb/nceas/metacat/DBDTDHandler.class�SaOÓP=olë6+ƒ!c¨Lp(°�=¿È#b"Qãˆ1ñS×=II×Î¶#ð³4?øüQÆó6L 1~è=íy÷žsïöî¯ß?~bËx’Âb
+ø�¸ÇÝ�qÚåëqùBž¿„3�³d˜¡çŒÖðÎ<†’[æßÁGü#zî!ýž�n/þgâ—é¹ïŸO�/ˆÏÒó©?ÿv/þñEzÞµ_œéÿPK°‰^"PKÓ¥Í()edu/ucsb/nceas/metacat/DBDTDHandler.class�SaOÓP=olë6+ƒ!c¨Lp(°�=¿È#b"Qãˆ1ñS×=II×Î¶#ð³4?øüQÆó6L 1~è=íy÷žsïöî¯ß?~bËx’Âb
 KX0P6P1P5P3 3Hb,Í´ñ4âÈ¥a`"ƒné0iâò&æqßÄÌ™XÁ¬‰G˜2ñS#‹Kï&w¬CKº–·/›QàxûuÍ?½‚ÿF×¾úÏÚ«Õ
 §jágWnùž§ìÈñ½þQrÝñœhC ¾å·•Àxc³±×xiymW5]%�Ù>²UW—„Ù]ÇS¯{�–
 ö¬–Ë’É�¸ãË·tŒè«¬N] w¹™³ä¿:¡GÓï¶Úq´bÜæ‘€Ñöíè¸K¢¤Ú=Ù³Ã–ôle…²£"Ë¶"y±Y�…k³¶½È‰Žß©ÐwufñSàwf‡FõüÈÒ½4”í
-Ì_Nèy]+U{ 5H›¸br�±ó¹ß´8âÕ<#Å,sØ1ïûò¨ãÊÐ:’§*\<h¾øpögðþù=j'ºÚœ?W]ò¹Ë½bŽ—<	�Ÿ˜¾ÒÁ~›ñ.¿VÉÇˆÙòwdÊân”+_H	ÜcÌqE€ãÒ\ˆQ¾.X�eZ`‡¨3Š_q3'N�%VN0J¨`™p®—çŽU¶´Œ,jü–T^A‘lœ9i>«˜>UÿHL+Z=v�:a:Þ?4×çVE.6°F«:­ÖiõŒVâ9ÊØ²,ñ=†™?PK¤…£2@PK&�Ì(-edu/ucsb/nceas/metacat/DBEntityResolver.class•WkwÕÝcKYž„ Ä
-”ÈIÀ²,G„7Ž‰Il+‘e°SÀŒ¥‰2f4#F£Ä.M(m(%)’Mú.¥îƒ6�&n
-Y]í‡®þ…þ�®î;²Žåµ‚%Ý{ç¼ï>gî=þçÿþöZÑ‡OýÈø1á‡îÇ¬¯ùaøQôã˜ŒïÉxKÆ»2NË8#ãÇ2Þ“ñ¾Œ³2>�ñ¡Œs2ÎË¸ ã#Ë¸(ãRëðdëñTA1lÃzô·ãìnCØˆ§Û±	{Äã`xF¬öŠÕ¾vt`Hp2ö°Ï
-ÚH;:‘Ãaþ`ERBwTØK `Lh<'¬</üŽ+ÈcJ¯*˜Ã+
-æÅãwPVð†X}/(8�×œ„£àM1|–‚àE1¨
-Ná%o#§à‡8¤àVð#|[Á'Bä'˜TðS”üL¨ýÓ
-~!¼ýš‚_ãe¿Á!	� uKØéIÍªÇÔ¸¡šùxÆ±u3¿[Â–*ÙÔœø¡ñÔ�ešZÖÑ-“ÌÎ*³ôº×JeÃÉhÎíŒŒ£:ZA3£5Ò3éŽ/Jèˆ$›ºô�>)l$Ws#iB_EÚW>rD³iî¡µÅEtÏÙZQµµ\c”ÍT&× s'ƒMèÍœZv>>W0â%u.ž4‹e'c•í¬F�÷Dê5@,œînÎºh8}§Úw´†ãÈº©;{$ø–ž!+§Ix|x_Âttgž¥`Ç4{g^s†'†3ó%B›Žô„ûÂ	Û¶ì0-†õ\XBÿ�+×�£B»‘P~ò›+Û%Íª�}CUS›sõ:Vé	¨$sY­(.ñ¥JJp’éLb|"œLOŒ…™ùé¬ê¨†•G–Óz.fÑÙóÓÎ|Q‹…KnELç¬lå¹Xž1ô¬+Vr£â²'<¹7u(‘	GÌ²aÄÂÝ¹;¬|{èú€„»Rº©¥Ë…ÍžPg¦§£’PÝbÍë¦@PS,‘`³ºéhZ6R™D*14Q&¼|ltÅÞ�$Æ
-›
-?]‰0¼7=\ß� ±Ê°_úÔbQ3s¼YÃ*‘àÉÒµ9[‰€›Ê2fG«½«6dË¶ÍUÂp	i‹âÏTZe%"�Ð­åÊñr¶47³šZŠ4Ge¼ñÛ)aûš’™½/Œ¨fÎRmZƒ?mNË–¯6§3¦õ+«ˆ»$aT+•Ô<…>ÔÎJZª³„�Õ%Çj•Ô@mH7^OÚØÌ¬‹Ngó3p…l%¨ªQ—4qÔ¶ŽWJäþÚQ?ªG,» åxæ7Ä¢4ÞU�«®†ªù•ÕÃËdíS—e¸ú&aÖo‘çã¨7Xðˆ÷“ð[¬¢nÏÝÛó½y�C™·”U¦µ@1™²Ê¦ãY¬ÄÝàT.Š¬bÏ¶–×‰®½"÷ëìŠ«Š_æ»TÏ·ß±*Kt±9XÇ›8üâ²Ð"ºwæîÎl8{)qS”>Ê§.ÎâÏ+ý^…¸ÎmŽŠ[iî>RòÈ.‹�.8›¢7qoTº�®hë
-<íåª®ÝI'@„ÚaÖÅ~%Êæ(BM¶KÒGn¨À‚Rºw	ÛyŒ{Bž[X?ôßÄ}±El
-¶pXÄKèiÁá�g	}”ò†¼Kˆóºðuø.ByIßÙ‚ô^î—¯a—kÂC!y±Š…E<º€=ý¾*Û'Ø¾•ì­ýÞ*Û+ØÞF¶pÎ“{ÛëR­«¤<_ Úw…Äb3va–ŸÍÜú»ülfgú9.s®Àt;8¾Aê	þN¢�™ëÄ[ØÆ9Ân-Â>mÛ´]„­ŸMÚ {´A¶h#œÒÞ(N3�géi¦èzzÎ²ü€šg©qŠRç(qž=Ýökçñ>f'Å'¸Ê&ïK\Ä?8ÿ—ðo6x-¢¿[Nö•�óì-§B„ô[‹xHà¿ˆm¸ÛEb€G¯öå%<ÒâæÇ[Âã­y½}ËŸÐ]-!"1™Þe<7¬´â×F¢ÐNl¦ðR
-«Iv¾ <ðvÃ¿gIý‘r”üèÏ±¦Æeþ®â\G7ç�¸‰'ðžÁàÆñwÚ¼L«_â|¿¥õ_a†^EIncÙzèá/Ñkè~ûvô~�ÉèÔu<ìyUùuìh»p	C½|U¢|êê½‰Þt_Pú¶Æ‚Òg¨ar™×ð`/“®�ÚGê-l™â|ÿ•Ø×HÕŒ]ÃUsÔ¨¼÷6Sü67&]©½v3DxŠ¯Õnb4@l†ù
-'ˆÍ~þGô,A’ÜÄã k'…1¤‰ë¦YAYfÝà¹`³’N�SDç+ê^ãùQÀ§0‰r‰#ˆ‘„»ù;îž*…ÿPKÂwÿ‹üt
-PK&�Ì(%edu/ucsb/nceas/metacat/DBReader.class�W‹wWÿM²»3»Y
+Ì_Nèy]+U{ 5H›¸br�±ó¹ß´8âÕ<#Å,sØ1ïûò¨ãÊÐ:’§*\<h¾øpögðþù=j'ºÚœ?W]ò¹Ë½bŽ—<	�Ÿ˜¾ÒÁ~›ñ.¿VÉÇˆÙòwdÊân”+_H	ÜcÌqE€ãÒ\ˆQ¾.X�eZ`‡¨3Š_q3'N�%VN0J¨`™p®—çŽU¶´Œ,jü–T^A‘lœ9i>«˜>UÿHL+Z=v�:a:Þ?4×çVE.6°F«:­ÖiõŒVâ9ÊØ²,ñ=†™?PK¤…£2@PKÓ¥Í(-edu/ucsb/nceas/metacat/DBEntityResolver.class•WûW×ÿìî,Ë)Š‘šêRY–Å5m´‚°”UXQÒ(³ÎÎ¬³³
+}¥¯´µiÓÆDMÒ4}FÒszNÕF(õ´ý-§§ý!§ÿPO?wvvzËÞ{çû~Îýî¿þû×¿£]ø0ŒÉ0Î…a…‘ÃÃ	£ÆR×e|_Æ«2^—ñ3?—ñ†Œ2Þ”ñ–Œ›2nÉ¸-ãmïÈxWÆ/d¼/ãW<�îv¢'‚]bÙ'–�8A'ÑŠÞžú"Ø�çÑ‚~ñxª�§AqJ6b†ñW"hÂ°àMEðœ°3�x#b:Ò
+$¼/y/F°ã‚##¤Låg,àe±è
+¾MÁ7Äé›ö-,*xEœ¾�¯*ø<ßÅ5ßËà*ø!.ˆ%«àG˜VðcÌ)x
+çü/)ø).*xO�üS
+~�«
+~#Ø~‹¿Š~�ywpIÁ2ÎK€©]ÂîhÇÈ‚vUKXš=—Èx®iÏõHøll^âìøÈ€cÛ†î™ŽMäž
+²pÅJŒ…¢åeïQDÆÓ<#gØQí˜ô×—$´DS[ª>)d¤6c"Ý¾	tª8;k¸wd{raÝ®‘×\#[meËV,“ÛÀéIßð­”:î\b1g%
+Úb"eç‹^Æ)ººA�{£U…X(íÙõ81 àôãr?–4'|B·LÛôz%„N”�'kH86x*i{¦·ÄRp¬«†{xÎð'3K†65íP»Ô¤ë:®J„G‰ª™íV%t?>ã5Ó›Ü%‹óñOÏìO°ý”¬¶±èóµlâ¡’I.êF^¸À¦JIðRéLr|BM¥'ÆTf~Z×<ÍræÔhù0mfã*‹Î]šö–òF\-ø1�uôÒs¾8c™ºOVð­â±C�ì9›Ì¨Q»hYqµ�&·ÇÕ¾ÒUŸ–°sÄ´�t17c¸ÚŒÅô´”j:¬yÓ4´K¤y«ºiÙ²l$Œd’#É�‰
+cÔ¡ñ±ÑßÎ
+'Ç“UN©'KªýéÁ
+”+uÀ�)iù¼agi‘>oè—kÞ6‚ºåHÐ	” ë%=Õéˆg¬7°„&½èº<%-�vHÎˆÚZÎ(�„YÚ�l1QÔ3	[7´B"gx�H<š]	mÛRfúÏkvÖT
+F•>cÑÐ‹ž°×X4iÓ¾Y×É©›‹vˆŠz¢¶ðF�BA›£…ë¯WêY¯	»*9M�­_´*ÓËFžÇfüØíÙúµYC[2ª"ÔMÌ»ÎµRUí_¿F5kÖqsF–þUÙ¢T_�›n“ŠøÚ‚ãý³ý‹šu²ùòaån\</VÛ±A\%! ZšáwXx5j«_Õ�VÃ“Û¼Çy±9EJ‹äSÙ§h{~ ó%»«”Êy‘Køìs&£ëÖä~‡[RUÒË|6òöœÒ!¦šŠÂb>P'ç�ïïœ ¸‡HaâeR_æÓAîâ/(ýÑ{@‘k„äÀ~B0[&?A¸ÀìŽ­â©˜ôm±úx.ÖÉÓ÷¹ÆÈý4ÐFÓâ‡bäätÃUHz�Øzî#±kªsûWð…Ñø
+žYFÏè}|ñ!vN57¬âs„^�º‚/¯àXüÿwÏ·­‰ºšý=¥lÑaÎn` ÀÙGŒ>M<ïâô³pØ¼CÊeÁ‡Há8ƒ÷qÅTå(\9W•ü—núþÓ,¥;×ðyÞW�Ö€oO¸d�Ú\W²h
+�u8×XC‚TÁÖàžå½j	½³5Hø‘:¤—q¡[®¸ ˆV¹Ú§eôv‡*è�@‡jÑºƒtP ƒÕh¡üi‰®µmPÕo¢
+üñ®»t¬Ãt~/žeÂ¸Gq�Ÿ½LÓñ'î¥PÞÀ3\/:Íï%VcÂu¦Z#G–_ƒfù�C7æ)Õäw�²MJ¿ŒQX˜BŽ”)Lbò<]a­º¬Ü+lg©Õã[Äm\eÂŠLÒ"m˜¦K¸‡¯áoœ•ÿÉýß,¨O8×‰A¶\¢·hUˆûPg³¼†£u~ìñ5¯Gk0ØU>„DpüÓb,ÇªÉ�U9DÇîùýqÇ×ý?Æ)´´PÂëÔöÛå
+–Ó
+<…7q7Yn·Ès�\·ƒ·‘¤W½0ÊÅÿ	$À½»�ŽWàPì#jxë]\ìü˜½5õž\b_u²)—±#þ1î£�1¶ÝGt]é®féÄ›¥Ð‹¯â`É>~Iºë"ô!öMq?p×§‘î®wéi¿KzXÏ'ù¦—¿PúpÏ³_{éD?ûõ{"Éžâi˜Ÿ“wš¯Ž3¸ˆ4S>ÆÄM0egkúEbbÄë&ÿ?PKMT`œÍ
+PKÓ¥Í(%edu/ucsb/nceas/metacat/DBReader.class�W‹wWÿM²»3»Y
 ØRšI,6lÈƒðh™¤<’,°HÂ# ÆÉî$lØì„™ÙöE‹ÕZ«­E´´BkKM[­…¤!•ÚÚRÅW�¯ãQ�=zôßðø»3›ec«É™ïÎý^÷»ß÷ûîÜ½þï+WQˆj|  ­`PAF�©àË
 Uð˜‚Ç<©à
 žRpRÁ7<«à;
@@ -47,25 +52,22 @@
 ÅÈ°$C´<ÌÇ¢'›�ƒzdé}˜Ï®1ÌUŽ!F¬÷ð½÷#‰øosµã8Az†ôý�°½^Á#,ì£Lõ»øR.õ‹­èŽ'£W/`ÁE¬.)á.ÄxÇÑÂúVÑUc¨b{lŠúê5_Ô_ï6m^DÑE¬Ò#P¢�z-P²  *ýo`“&O ´;"�¡Z@^Åf-ÈÄE‚n®ÕV±HÐ[¬ÊMa¬Š¯£hAáÆ·&w~[.[ö5˜ƒªØñ+ø;°†u|ê)Y…;±šÜ5ðZ¾Ý
 �0ÞÀ±	
 òFÄ±	íät1g=hA?ófÒÞ¢ÔÆV9ÎülÃãä=Ao’ø]–ËR”«
-€^ECe[´lwk>ÑñÏD|£XK°r¸‹Èä°^l}Q·À²PlC�¦T—Mu{Dûî‹®A‹È×°¦Ú…‘?£º‰DÀ®®¤P¼ÉâÍ7	®º=#¸ý£Ê´´ZÀ=îé-õô˜ý¡¶¤`†ÇóS§iæ“>Eä�$êNa�Œ%”T°•—ó8oÀ³Ìáfé,ƒçˆÏçqÇãœŸ`«ŸÅKlöSlö¯ÉgÝOÁ×éGòüzóCñ¤ÿPK·V¦/!	ªPK&�Ì(1edu/ucsb/nceas/metacat/DBReader$DoctypeInfo.class�QßkÓP=_›&kš¹­›ºéªv«Ðfnñ}âƒ+B¡(XñÁ¹M®]F{#Éí ÿ•‚CðÁ?ÀE}™ú&âwÓMqj çä|÷äûu?þ|ÿEìâ¶ƒšƒ¶\Öå2
+€^ECe[´lwk>ÑñÏD|£XK°r¸‹Èä°^l}Q·À²PlC�¦T—Mu{Dûî‹®A‹È×°¦Ú…‘?£º‰DÀ®®¤P¼ÉâÍ7	®º=#¸ý£Ê´´ZÀ=îé-õô˜ý¡¶¤`†ÇóS§iæ“>Eä�$êNa�Œ%”T°•—ó8oÀ³Ìáfé,ƒçˆÏçqÇãœŸ`«ŸÅKlöSlö¯ÉgÝOÁ×éGòüzóCñ¤ÿPK·V¦/!	ªPKÓ¥Í(1edu/ucsb/nceas/metacat/DBReader$DoctypeInfo.class�QßkÓP=_›&kš¹­›ºéªv«Ðfnñ}âƒ+B¡(XñÁ¹M®]F{#Éí ÿ•‚CðÁ?ÀE}™ú&âwÓMqj çä|÷äûu?þ|ÿEìâ¶ƒšƒ¶\Öå2
 p
 Tx=¬`ÉÃu¬{Ø4°m �+„µf«{$ŽE0jôt«Á>¡Øl=#<ove4ÆaÖT(EŒ¤¡ÐAûÁ)"™îÿûóÿDLrû^¬b}Ÿ`$‘$,žçÜ3vB¥�„zòJvÔË„àu”’éÁPd™Ìõ¹�–º±’�Æ£¾LŸŠþ�KTg�êö’qÊ‡±q”{¥¥ŽC‚%¡#9ý2­nÎ)KØ™ãhü5–;�º}^æLL+UXô&™–£N›°ü§ñÇý#jn5ËO_ÄïRÆYã.ê|ÛEªæzA¸óÌÝç¼yÆÛ9[ìXÁ2c•UÌñsËËß9Á‚O'(°
 8þ#w�Ü°X¿a3á*ã*Œ§œp�SœÂf.ã.á3Vñ…ÕWÔð
-[øŽ&Ÿó&ùlZ¶ÆLÌ%ÿ-J¯§´óàÆ[3­ö+ë3­ÎE«Ë“nä{XÅef—£~×@¿PKß>ËXPK&�Ì(*edu/ucsb/nceas/metacat/DBSAXDocument.classuV[WWþ&äLUÐ¨±ZF«HïHÐhJ"mÅ!16™‰ÉD°JÕ^ìjë[/KûÔ‡®®U»*®h¯}é_èsÿFW¿3“@„¸VfŸsöíìoï=³ó÷/~Cºð©“^LyqÅ‹/TnxPð è�éAÉƒ[Ì{°àÁmÞ÷àN¼6¡!Aºš±Ý�p£§2ö‰Ý~ArP�CÍx‡…Þ‘f¬ÃÑ&4ã˜8Ç^AN4¢	}ÂA<8)Ì„Ù)A›x·
-‹]XFQA.È˜Å˜Œ”8¦ñ®
-gd\Ã´Œ9¼#ãº AÞÃYAÆeäpN†ŽNËÈ#&ã®�.â²Œp^Æ=áù¾ðò£2>D\ÆG‚÷‰0{ˆ¨„†@ÇY	›±ê-µ'«ês=	³�ÑçNHØ\eof{Æµb)k&4sµ aª¦–Ót! »	‹^’àD…o—zÎ]�èY¡¼9]+‚P 
-k¨tíšV ¿}¯WQž/hyµ ¥k£õÕ3™x
-Ÿˆú+þ†
-]×RfÆÐOœ]«]ß¯»/£gÌ“LÍ°‘Ö$´†‡ƒSa#Uu2#…‚QPæ4Ó¤�’I÷*&¢ñDd<©DãÉ1e!—�IWŒŠJ€ÛL:¤ÃÔéVìÉÒÕœfmÌÛy­C™Œ]Œ$”€^ÊfCÊ€ýë� ±Bëc]‹—r³Z!©Îf˜ÏŽ?c0mÝ$MÍ1a­õ
-é«›	ÿ$"±ÈpRA¥USUFÆÇF­à§¨Lž‰ŒG,©QéWÚ“‘©d»2×€!Àb‰êéUf4®(J æòV¹Wj.É˜3«µS$ÖÜ¬´ÓÓh$ž¬ÊVÝß¡Œ�‡#ãÊÐtå2	]•Ë_)ÆL&=SÔnv§J…Â-5k‡”.©Y	M	£THi#‘ß#Ï‡“‘U•T‘¤U1¥u¯�À*°8³ƒÔ|^Óy½+•5ŠôäL1å,aŠ2µåæ¦‚e%ÁSé	Þªk›) KØ­¥K=¥Tq¶GOij±'§™jJ5{^éLhZªd
-/lLò£a2¹�úÁq7ª‹ê5d–?y´{Å6NÚ!l¬Óa6¬ô×Øì
-¶¿õßøWt·‹Ä]uj±’×Æ¼ÝÍëô§„m¯ÿ4°Ñ×~öØè+Ÿ¼±ÈBJËÛžZ×~
-Y][àÒ`”H7äí+jäž¼À�¥yÓJ³‘]¬æ´±X“·ârÞ¶V·##7|=“MG²—^Ó¨´Ì2¦V­_Òa'GŽ uˆÃ�CÌkå�±ÖLe½^Y¯Yr7$©éEžÆ8nÝ\Û:Ÿ£¥3ø¾Nåötú�Ï°µÓïz†m”t>¥Š„K¤oqÝpb?GßŽÉƒØ„CØ†Ã”uS+‹HÅù÷ÔÎ/7žêü¾26Kˆwµ:ËØîÀdWmz�~žwò-rù\O û�<îpàÅ›$|‡¶^çOØõ�Ó­Òs´ú�Kxk	—Ð±„Ým?ð*zÑ�õ•�p6ƒˆ¸Âg†Óû*|P±ƒSy/‡r�ù:Ä\ôRÞÏ\
-0?ÓZÂMŒTßÁUâêbØþ—±»-f‘”s·¢ú%16pÉó˜­®2Þv`4äÖe´7 $m)c¯¡2Þ”0ª [7Jp!Òî§téblGWa¹Kî"Ÿ{LøþM¹‡ÎüíùíøŒ)ÿœ6‹´úÇðC¸Cë�­ø/%[”b�ƒV|
-V|"ñ"Â=VX~§«foÇ(VQ!—ßeWÈís‹
-¹ÈWˆ	y¥D®WJäª-Qgp	Í‰)\^†ÇFÒ¯Y¢o(yÌç	ú[þãzBxK,Ást Ì.{ÁR½Ä0~ÁüÊ¼ÿN?�éé¶ýŸ˜Ç_LÐWôó°
-™E²!?²à:,¸±à
-Ø ÀºÕªLÐÍí6{k£Z ìTY+UíÙú)i±RÂ¦/Ï–å¼¬‹1-Á•â²|I«¸„Í¤½|úïIvW›u[ˆuÂü<ÂÂž¦F”’sÜÅˆ~”vq¶ñÛö<[önñe^¤Ö}b€	¶ÁqÞpÕzå'þPKõ<e3RPK&�Ì()edu/ucsb/nceas/metacat/DBSAXElement.class•Vûs×þÖ–-Y^ˆ#0©�ÀH�¥µE!ÁÆ?D•ecÉ&¼â¬¥‹Ù ¯äÝ˜„¼Û¼�W“¾_	?t:�dRQ'3ù)ÓÎôÇöÿéô»»’Pƒ<CgìsÏ=çÜóøÎÙ«ûÏÿ|óÚ1€ÏCx&„K!,‡`…°‚‚‚B%„Ë!<Âµ ^â• Þâý ®q#ˆ‚ø0ˆ�‚ø8ˆOÂØ€ÇÂèñÉãÝ¸‡º°CÝØ„á.Ü‹ÃÝØŒ©8¦b´½8Fcòì¸$’LJ“¤äŽIò„´;.¤¤«aÜƒKEZú›’$#·Ó’ÌHrRÊfeY(§¢ˆ‚Šç±¨âœQñ"®ªx	§U¼ŠU?ÁYI„ŠŸb^Åk8§âuœRñ†Ü¾‰9oIîm<©â©xWÊ~&�}*|†¼ŠŸË¿À¿ÄS*~…¿†¡â78¯â·’ûžVñ{éàXRÐíOyô„‚ÍÑþô3Æe#Q4¬¥DÖµMkiXÁ–ºØY)&f…S)ºYáþP‘u
+[øŽ&Ÿó&ùlZ¶ÆLÌ%ÿ-J¯§´óàÆ[3­ö+ë3­ÎE«Ë“nä{XÅef—£~×@¿PKß>ËXPKÓ¥Í(*edu/ucsb/nceas/metacat/DBSAXDocument.classuVkSW~ra«‚†zY­–�Dâýo4’€xié’,›ìÆdÃEk¯juÚ/�~ê¨Ó‹SíÚ™þ€þ…~îßèô9›ÂLòžsÞûó¾ïîÙ¿ÿûã/4ã¾râ†SN|àÄ´ªw(8PtÀt äÀ‚‹,9°ìÀ}¸á„ß
+‚iÅô¹Ð‚`+d»c‚ä„ '[ñN	½Ó­Ø†3n´â¬8žÇ� ç]pã‚ppÑ
+.	³ËÂì=AúÝ<ˆhƒb–‘DT�ë2f0*#%Ži¼/CÃU³¸)cwdÌ’ä#2.#‡k2tÉ0pEF1éCÜ–ñ	Æd|*<&¼|Ž_ .ãKÁ{,Ìž *¡ÙÛ;,a§·7vW]PƒYUŸ&ÌBFŸ;/¡«Ê.ÞËÇµb)k&4s£ aª¦–Ót! »I‹Þ’`óF…ïN.�œÛ½Ña¡Üå�nAÀÛ€¿‰5Pš�Õ
+ôwtku‘åXAË«-]Ÿmg#“É-øDtÑ»îoÐÐu-efýüðfíÆ~[.dôŒy‰¥4Òš„öð@¢*l¤J"¡>aCf¤P0
+Êœfš´S2é�"a2ODÆ“J4žU–rÙétÅ¨¨x¹Í¤JÁ0L�nÅž,]ÍiÖÆ\Îk½Êdl"’P¼z)›
+(—Ë¿^	;´=–Ñµx)7£’êL–‰u–óÏ,[F7	ASs,X{£Fv6,Š„‘Xd0©ˆ¤Òª©*Cã£#Vò‚STn\�ŒG,©HQ¹¨ô$#SÉ¥?®Cþe‹%º§W™Ñ¸¢(Þºämp¯ÔÅÌŒ™Õz(ë"+=ô4‰'«²
+ñ{•Ññpd\¸Y	&áH%øÍ˜Î¤§‹Ú½¾T©PXP³å”Ò%5+Á�0J…”6”õ==1îOF6tRID’VÇD–VÜ2«ÁâÌ	RóyMgx{*kéÉ–bÉÙÂ;djµá¦‚e%ÁQ™	Îªë2S@—pHK—‚¥Tq&¨§4µÌi¦šRÍà“ImIK•Lá…ƒI~4L&·1CŸ#8îF´bQ�£†ÌCíe!ÁÅcyVÊÆÉr
+
+&LÂŽõù�¹ËQâû¡ñÿ†nb¹HÜU§+9_0ËÓÜÑ`>%toýjà o~íqÐ×_y×c‘¥”–/{jßü*dctm‰K³Q"Ý‘/‡¨“;òw–æîõa#»X­©«XW·b­n»«Û¡‚‘œÏdÓ‘lÅ¥Ó4ªm‹…Œ©Uû—4Â8À+Ç	�6‰;†»&q7X+/kÍTÖùÊ:kÉ[ ñ’J�Nð4Êë¶…ë~ßk´ùü+èô)+8ìóØV°Ûç±¯ ›ß+ªH¸Eº�7!ÐŽñê;Îkòvâ$ºqŠ²>je©8ßË W»ïwìzQsÑb1ï�ÞÃPMUª©z^nPM‘ò¦«¨~ÇØÍ\Eºêw¶Û×ðNF6a½†žf¬˜kx×†ÀÞ–pƒËN	Ï±mä7¬bß*½¢K;“?ƒí•€§y³ƒì¼‘í¼‹]Ì±•kJØƒô`™ ïÓ&G«8Ë[z€W¸„GˆVü—	Š"=”b®~+¿f+¿�Íc¶ÒòØìuûrŽbÝ/!d÷Ñ¾YZ:[¾‡ì±“¯4!&äˆý!;Qü	×Ívé5Ú=vOÇ*z‰Êç_…W@³a
+·kÐâè }Ìž<¡ä)ÿÏ8BßòçáýÀ<G/~d_B?c¿à*^°î¿ÒÏSzzÉA{…E¬ô#ËO2›T†ü�·É‚ó¯ƒõ¬»­Îø[¸í.oË¨ý¨r©ÖÐ%Y…j'Ô=M[•¤Í*ÉÞ&ô‹qÝU«Ë¶Ëâ_o.›ÀÇ¢Z�[è"
+ñ�ù^ât]àÇÝvëA„ùÝ9ÄÆ^¡F”’kÜÅˆ~„vqÎà(¤1ŽÃuŽA‚~Cô<Áo±I|�sŒð¡õ�MþPK·Þi7ÙÄ
+PKÓ¥Í()edu/ucsb/nceas/metacat/DBSAXElement.class•Vûs×þÖ–-Y^ˆ#0©�ÀH�¥µE!ÁÆ?D•ecÉ&¼â¬¥‹Ù ¯äÝ˜„¼Û¼�W“¾_	?t:�dRQ'3ù)ÓÎôÇöÿéô»»’Pƒ<CgìsÏ=çÜóøÎÙ«ûÏÿ|óÚ1€ÏCx&„K!,‡`…°‚‚‚B%„Ë!<Âµ ^â• Þâý ®q#ˆ‚ø0ˆ�‚ø8ˆOÂØ€ÇÂèñÉãÝ¸‡º°CÝØ„á.Ü‹ÃÝØŒ©8¦b´½8Fcòì¸$’LJ“¤äŽIò„´;.¤¤«aÜƒKEZú›’$#·Ó’ÌHrRÊfeY(§¢ˆ‚Šç±¨âœQñ"®ªx	§U¼ŠU?ÁYI„ŠŸb^Åk8§âuœRñ†Ü¾‰9oIîm<©â©xWÊ~&�}*|†¼ŠŸË¿À¿ÄS*~…¿†¡â78¯â·’ûžVñ{éàXRÐíOyô„‚ÍÑþô3Æe#Q4¬¥DÖµMkiXÁ–ºØY)&f…S)ºYáþP‘u
 W,K*ènÞ£g¢)é[.”uDSõõ„\·DSw†”Š@ÔÓëÑê;Dã•„ÍÀûÖ7—9ÎØ¢lØ¢Ðœko«#óëÈYÏÞòÖÝ•eë³±èí¬'J–%ò®Y²Ö1ž¾[ã´(T•¼³˜°òÂpËÂ5ò†›˜ÏŽ=™,ú�H�J¿‚6]SÐyØ´L÷ˆ‚®±\n65>—K*ÐÆ\ú[¬¸B³Œe¡-WW³J®¶HA¥XÜÅöM”
 BÁ½Íže>
 B“ÓsSÉLNA0™Nú\$iÛ%[[®ËD5³0Äà÷ùBÓr„í‰-:Ò¢
@@ -76,7 +78,7 @@
 å#ä4Š|ZÔ?QC}GüïØ‹©ÁX¤=®‘›èþ
 ;"Ìbà6([½2oðÔ‡þƒ1?eÌë´àSÄ÷«,ÑB¶èßñHÇØ$A‰t­Ag�›èñöáÚž@Ä×p }�Ýcxèsdâ‘Î/°·/ {ôÐöh¨Y†(|p
 ‰v·Ç·ÙÓÊ¦ß³‘ÈïTpJ®Ö#ëÖ!b'Î‘6½ÎHFiÀOãZ?†ÂÂ>fÑõF<ËYóÿá%0clÆ(_˜Gh3IÐžÀv®»‘†Ž)ÎPÃ˜¦Õw'9E³Xä^ ‡ÌÑß<Ûvïá,ãf¤s|žÇ_8ÓÃ¾'ÿ<�±µ
-þˆB­™¯×š9ìÁ«zðNé5põŽDº†^ÃbãÇNo.NG¢QÜ~–~TÀ%º/²ÀK””ù,^ÁN8œ4—ö&OT°—™’ü¢Ÿ£}ÊÿPK]Éî�†PK&�Ì()edu/ucsb/nceas/metacat/DBSAXHandler.class¥WmxW~‡l2³›�@ @¤Ð”Ïd,¶ˆe	X’]`1Ù¤$­2ÙL’�Íîvw–†Ö¶Xim+­m¥Õ¢h«mñ[ÈÆEªV´¶ÕªµU«R[ýã_©ï™™|Ñ…æyšçÙó}Ï9÷œsoî¼ðßgO£+ð/
+þˆB­™¯×š9ìÁ«zðNé5põŽDº†^ÃbãÇNo.NG¢QÜ~–~TÀ%º/²ÀK””ù,^ÁN8œ4—ö&OT°—™’ü¢Ÿ£}ÊÿPK]Éî�†PKÓ¥Í()edu/ucsb/nceas/metacat/DBSAXHandler.class¥WmxW~‡l2³›�@ @¤Ð”Ïd,¶ˆe	X’]`1Ù¤$­2ÙL’�Íîvw–†Ö¶Xim+­m¥Õ¢h«mñ[ÈÆEªV´¶ÕªµU«R[ýã_©ï™™|Ñ…æyšçÙó}Ï9÷œsoî¼ðßgO£+ð/
 ·hxXÃç4<ªá¨†'4<¥aXÃ÷4¼©âiƒ*N¨8©bHÅ*~¡âE/©xYÅ/U¼¢â×*~£â·*^
  
 ÍÌP‰–¦"@Z´0×Šb›€v?¦¡CÀu¶Øá‡Ž�B9 Ó�™Ø%^v—c.® 7øˆ°jO³aÛ%l"€rt‹ÌY�Èz…íÊ°W<ïÏII·_@*€éH•í�’nVâæ„µä%çý¢¸IÀ€€nÖqÜ-à°€ûÜ/à!_Å>©ãø²Žoâ˜Žoã¸ŽïàqßPÀt|�éønÕq·ø¸Žâc:Î{FØç„ú‘ÈþXŒ"ìó. ì§B�Å]:~&àWøŠŽß‰ç×p›Ž×ü^2ý#îÔñ¾¨ãO¸GÇ_dç$«·%¡¿‰—¿ã^ÿÀ!çeÅ?qH�¿¦¦½³=	×((©­‹9p«‚YµuÍ{�ýF(i¤zC­]{Í„½îBq»�µR½ëœ5ÛTÕÆŠjç“7æ{zÌ,µ>j·Ú*hií;ÃÍd‚¡ªhôå“2M§ª˜9[VD^Ürí¤,‹¯�ë­ÍÝ˜5¥S)îÕJ§Õúâª­“u,¾¾¸ñ‘É7›ÝùP>‘ë
@@ -91,7 +93,7 @@
 -nå>ÄÊÅ/ÌîÝ½E×oLpõóÑ–V;R®[Xæ¤û<ápÏ¸&ù&6)¾¢²¬~y‘&½Æ&½Î&½:!äŸñiÏ×1¯I;|%'>H¼fu‚×a“[ Èé��½Ä²¹Ý‘—RNÓºw(W±iT1–àB$`k²“ëä	ß…Ø�5¸ž¿�ÇªcBÒíâvŽ¾”eå¸öè›¬¢“²ÅLq—¡Q*Ä_cwŒEžÍõÀFFndä(ï—-ü2¿fB´·ð �;Ðx^ T(aU	klóÄ‰V)ûˆ¯".u».DÐ·‡×Ç¸S©‡o‡ÈC3;‹òjK}3¤dg¢VjÎD�ânÊMû|˜ÛšêlËÑFcÁ–x¦f¶?6R€j_µ:¢FMX+Yã?Ž†åU<4WÇôþ°ÏÁ«Ã¥^.[¾¢€p8 h]¸¼Z£—òšù•*?½‡ÿßs²­jÍ-§Â¢­Efye½Ÿw#p3çîÎí­¼\oã÷ýí<Ì±wÐúwrÍ!®ºëq/"8Œ­¸�
 ?ŒmôÐÉÉÜÃ±—×ò€|áãaJŽ>Â‹ü(?Ù�ñKü	š'ñ
 žâ—õq¼ÉKý</žóŸÂpLñá¤2
-™	í|Ò¹ô?ûPK<–ö¦‡PK&�Ì((edu/ucsb/nceas/metacat/DBSAXWriter.class�Wk[Ç~„Vˆµ!Ä6Ð`GØ‰-�¾‚68’¸S×qiÂB«¬V\œ&é½i›´M›^’6±·¥ÍÍ˜4Â�Z÷[?ôKÿQŸ¾³ ˆð“§ðèÌÌ9ïœ9×Ñèßÿýü!*Ñ†‡¼âÀ«|ß�8ðs~áÀŸøÈ�¿Ëx]Æ2~"ã§2~&ãmïÈø­ŒßÉxWÆ{2nË¸#ã÷2Þ—qWÆdüQÆŸd¬ÊøXÆ'2îÉX“qß‰Ctâˆ .Aj1äD� i¤—�Ø‡ç�p"äD� Š �;Ñ€H5¥Ã‚ŒT£	£BË˜_Á¸-‚4aB(˜à+NìÇ”À]uâILÜW�¨Ç5!ýš°åº /rC�¯}ª8M`Uàf¼M]�´ † ¦‚×�RðCÌ)ø¾«àÇøŽ‚7ñm¿DLÁ¯ù5üATÁ‡xQÁº€|Š›
+™	í|Ò¹ô?ûPK<–ö¦‡PKÓ¥Í((edu/ucsb/nceas/metacat/DBSAXWriter.class�Wk[Ç~„Vˆµ!Ä6Ð`GØ‰-�¾‚68’¸S×qiÂB«¬V\œ&é½i›´M›^’6±·¥ÍÍ˜4Â�Z÷[?ôKÿQŸ¾³ ˆð“§ðèÌÌ9ïœ9×Ñèßÿýü!*Ñ†‡¼âÀ«|ß�8ðs~áÀŸøÈ�¿Ëx]Æ2~"ã§2~&ãmïÈø­ŒßÉxWÆ{2nË¸#ã÷2Þ—qWÆdüQÆŸd¬ÊøXÆ'2îÉX“qß‰Ctâˆ .Aj1äD� i¤—�Ø‡ç�p"äD� Š �;Ñ€H5¥Ã‚ŒT£	£BË˜_Á¸-‚4aB(˜à+NìÇ”À]uâILÜW�¨Ç5!ýš°åº /rC�¯}ª8M`Uàf¼M]�´ † ¦‚×�RðCÌ)ø¾«àÇøŽ‚7ñm¿DLÁ¯ù5üATÁ‡xQÁº€|Š›
 þŠyŸ	Í9Ì*Ø@VÁ,*ø–|Žey¡åˆK¨tŸ’pÀ}24¯.ª¾¤ššõ�›F"5Ûm	¯H8è”•rÊlî¡“	GÜaB÷]L$µî"6¥™¾É±q�Û€n5©@SºÅ™�o‹Æ45¦×ýna�y1éè©”5zÊ‚wÑ²²Æz¿°?�ó8Œ2pžw¾ÿËpÄÞÿçÞ=
 ß	ž=O(ºgÜåE!ÝP£IÍ·¼�ô¥U#£¾ÅNßxßÕkQ’Ð2JŸpsû¬µ7£.û‚ÁA5KëÚ%Õ£Ù-e–BžÜ	H™	seLËèÉÅ"âð.„aèF©†Cîkåãïè‰&©„Ù+ÁÞSœØzL“Pì§ƒSFÂÔŒv±YÂÑMë\iC�j™Õ¸âÜ–™Ób®¸nø]twàj``dbh8âì‹CC‘K®±�ÑÉ¡±� çÀrTK‹Ød$Ô†)-’]˜ÑŒ	u&ÉC–m	õåê÷à)wŽëY#ª‰Î“par¼ïÒ€ß% ®—\=qÊSê‚ÖëêÉ2‰Òj&³¤±^×µØLÆ:æº„æ)C§Ÿ)ËN—w©Æ¬…LKKã¦¦ÓZ*ÆItN5úL0Jk$TÇ´¸šMšÁ~	Ç´XÖ—�ff|©¨¦f|š©FUÓìß.	'öDíÌù£ôÑÁ-}G…*„aoP˜c@5'ÍD’×¡fj‹[!Ý/†öŒÆNPM�üjÁ˜Ðyµ1§³šÙ7C;³¦6¢šsL9a‹:Ë½5\ŒzZ3ÌÖ˜(¹„šLÜÒ
 �$A)½8™øÒeáæã¹ÉÞ*§nIé°¿¶'�d~#ºyQÏ¦b%k·!Vçlª*p¶quÛÜá™y–ÛV¡,Ùkå/Ð�Ø•Œ©-ì8gbÎÐ—
@@ -100,20 +102,22 @@
 óHŸ¡ÃãµÈº"m­9ô¬ÂYÇé¶ÎåÐ»Šæ«ýÅÕE®îóí»ŸOÃfž!F­c­èçã¸ÎŸF5f(�ñ£ñµ'.Æ�³8Œ9œàÜƒZ1�³œwá&ÎÓæ÷~“<é1"·|1Š¾ü‡ÞUq¼±Ó—<ê¦ó¨�nÝÀñ‚8±ÜóÛšlm–ƒ§ü6zÑdÛtÊµk]·µÞt³íè ›bì#ãè–›i�.º™¥‹‹D,ñ³7Vˆ]âî[8Mã{9ï£ù¼Œç£xãx/pÿNW«ñCRHó]:Zi¹šÃ™P½ýž	{ÿ…oçmwPÛê­ÌáT�/‡!&ñü{hi-pn£!�Æé:ß\ÚÀI
 	åÑ<]_%1Fžµ©<L×WoÀýO7ˆ	þ?QtÍÃJßÝUø€?%>äcþ#ÃÇ8ƒOˆ¼ÇÏÑë˜ä¼B<Ò‹ß£¹2Ç))œ‡"rÑÉ£FLÚü¶<œbæõWåášÞÀÓ~{G8y*ìeŠú¼"öýÞ¦ªžó6Ùsì¬<ï�©À%\ÞÊA/v€
 RÁ_l™¼NÙüÑò&sðNÑ¸³xÝx‡ñ—{_ãîÛxwhü]FûfÊ2^²1“v¡ÍóÐþ>ðÜzÚÓ+ÆJQžÊÎ�ÇÖöTuF$¿�¨»¨YG§ß¶
-‡ÇÎ±ÞÑdó¶=€_x¸¯µ©j­ëè™¨—¶ÓP¨¾�P\Q8€‚³œ|:‡gWQyŸ65 Ê†ÙôT´XKvú³çxMtáç§‡i{–÷2Epœ~zÙ‚Ï È†¢÷—)ä*„0ÿ£ÜÇ0Ûp:kqc¬B?/œžö=ëÚyùPKÚ]K”ÆçPK&�Ì(*edu/ucsb/nceas/metacat/DBSimpleQuery.class�W[t×ÝƒeÍh4@Ø $”�&©_XØ@ ƒ€€-ƒA¶ÁÌ#„Œ¥±-�5bfÄ#M›W	MÓ¦!iÚ”¤i“´¡i’†GbÇqKÓiK?ÚßþµŸY+ýìoé¾#Ë ¯ÕU­¥sï=÷<î9ûÜ«£ëÿùä*ª°×Œ*È(8ªàIO)xZÁ7œQðŒ‚³
-žUð-Ï)ø¶‚çœSð¢‚WœWðª‚_)ø�ŒŸÈxCÆ»2Þ“ñ¾Œ_Êø@ÆE—d\–qEÆ‡2>’1.cBÆÇ2&e|"cJÅ—°K….H½ Ë±[,“*–¢KÌºé	ã+Ø"o¯ ½!¬D_÷ _È
-Ý}aÜ‹A«°_ËƒaÔá�Ø}H,‹åÃ*–áˆ0ðH_†)4†TÜ‰” i!l	ËÃÂïˆ†ïÀ¤ È×y\ÃkðyTÃ�Äîëø�†ãûÞÄËÞB^ÃOñ˜†Ÿá¤†·q\Ãd5ücÞ�£áBä×Èiø�˜}Šc~‹¯kø½0ð|UÃ5œÐðN	B¿Äi
-‚«áÏÈJX¨êz<–¶S…1+çmQ%,"cf­ó#!DÞñ‚åœÞ"aI]}ò¨yÂŒeÍÜH¬gè¨•ò6ÝÊîóœLn„ìÚÛ=ž�õZn!ëõYB>ZÚ(x™l,‘£?Çô2vŽ{Uuõû|zPB ®³~—„•íwÞÎÚwÕíº]a{axØr6	«»„Ð²º¢HÆŽíá¾G)Ëóõï«»=ÊŠ�×T¤��øÿ£É¦º
-1ÍÌš¹ÅEÖ÷8VÞt¬tŸgz–@•*õs«øxì4ÝQÏÊZ·X–á#øÿ§ì°mv.Ç$ë Ï-ÂymÝ¡Ê§RüjÎ¤Y©ª?Í™caáe¼¬usË;�‹P<V,nVÿüxÌñ«ÔµüÛPßzj,«Ÿ°—®7¯ji^³j«ØPâ©l&—ñ¨/ÇKCñ‡j¼ÌŸ¿1í.ŸÖÓâ³\Úì´%!Ò¾½/3–ÏZ{Å™šE�¬æÄþ¶ÄžþÎžn}ç¶îödg÷½7±w ³7ÑN•„ãØŽ>byÓ gÒï¬š8•²ò"a.¯y2“³ºcC–Ó/`%ª+Ÿ¶*Ý²š9z¬/‘L´õë~üMÓ±7M‡ÚTŠ_ïèíéÒ™Æ#¥wÅÕw&zE=½³[¯+74#ŸcFJ²bž6=SOvîNè[õz†Øgœ”Õ‘mèÛ¶#aèâ¤ú¬–Þ.=^p-‡CÞtÝ“¶“Þ¢J¹~�‡%Ü=èØÌ^ÎÏ’në¦3R<íÊ•+	›™Ï[¹´„êTÖvé0�b*mÚ6‰bûv	÷XéB¬�r‡b¹”eº±1Ë3S¦›u	«æëâØfz¼�|þ,ÇamY§¬TÁ£»ùÃ™\º½”@înî“&yl&ƒ³.ËuÍ
-k\Ü|myF.‹`²FM·Ëv¬DÖš¶´¸T	�=7k¦Œ[Vô™êhË2�Ý¶×aréÛ}‘2î‚nñ¼wÜúðÍb•N[[ùÕ›-{ÚåÃ6Ëqÿ¨cŸ,úâ
-¥+áÎ¹ŸGÞ�Û±xn2ûö&Ë›.³PSñ§­t˜ÙO¬„{�¦‡R†í˜©¬ex£™œñ`ÖN™ÙQÛõŒ–õ­-†g¹´8f�&^�13C[�œuŠÌ°¦ÁdZliûöòPW
-7'Íi'Ã·¬¹Çgµû–’]ªùb&ÊÂX˜/bo¦ŽõSƒG•}N–f«òB)äÎT–âÙÅ){¢¥ìÇ€yPD?ãÏØÜp�óMØ�ð]®VqŸ`¤æ
-Ö]âLÂ÷HUÊ+PÍ6N­×B~-G±³°a
-
-ÒGXÛÐH2£¡ Kª#„ãXÀùKä(lP£¸wQŽUÑ½ô:Ð8®›Bý�	4u…6$#(²d(’jøk#‘I´ÍC÷ê@ã$v²Í�Äý9ðý3Ô¨:‰­î_Àµ¨˜Äó°!U«'Ÿ#UƒÅ™UåâL™‚No�F(Š„ÇÑRÇšIË`4øVDCB"¢M 9$7RM2ŽN_@žX d! —	(3ó…€"‚3MSX~ 60�ÕÑ�ÏÚ1x3ˆšðùq†Ö*±Ñ\a¨—±Ý7´HRÇa”Ìt4]d—J‹¥Zfµ˜ûÙì�2×�#Œ'˜û'±Oa	žf9œá÷,óÿ!=KàŸaÏü<ñZqµÛˆT-íÁË8È¢I³`rø!Nâ<žÅ«”~�ýîëø€%õ¼�¿±Kþ‚]ñ
-¼#)xIš�w¥Å8Ã½'-ÃûR+.²®ò$E´¯³*ÚjÃÕà›Xrë#K‰s¼ÔPÕšl´v5T·vKF€Ro!|ëŒÀ(
-ÁV#©�šVŒmFõ–ˆVO Fˆƒ�ãØ`È%XEåH¬%¢‰,,Ž~*«˜ÊF‰Rê8¶,¡
-Ñð$”ØÇ/§Y¤|ã§"4­<OàÚR™6u6K8ã]‰ÍAÂ&`O\€žáÝQ³Ñ°£‘Óq´_@Õ%�!>gïžÆðmþkšÄâ×‚Z^¹¥XÏïb·‘Wòâfó8š°™q¬ÃVrÛ±		ÎÚ8Û�ìÄ vã$‘B†ÑM,{p‚èžÃ^¼‚^"ÚÇ*ëÇðïÊ>þ)À_Éÿ;öãŸ¬€Ïé÷<„á0þ�‡‰ó)ˆõRˆž%Ö…xT^ø/PK)s´´}PK&�Ì((edu/ucsb/nceas/metacat/DBTransform.class¥WûwÇ½‹%íZ¨„
+‡ÇÎ±ÞÑdó¶=€_x¸¯µ©j­ëè™¨—¶ÓP¨¾�P\Q8€‚³œ|:‡gWQyŸ65 Ê†ÙôT´XKvú³çxMtáç§‡i{–÷2Epœ~zÙ‚Ï È†¢÷—)ä*„0ÿ£ÜÇ0Ûp:kqc¬B?/œžö=ëÚyùPKÚ]K”ÆçPKÓ¥Í(*edu/ucsb/nceas/metacat/DBSimpleQuery.classÅWëwÇÿ
+–¼+iy	l"BÊâ$T–e›€a-ž¶Œeä–�1$!kimd­X­·i’¦mÒ¦¤yè+
+mÝ¦IË#±1N�ÒB›Wß�súôCû¡ßú±é�•eÉX>‡~ªÏñ�;w~÷ÎÌ½¿™Õ|ðŸ«×P†ZüU„."-â˜ˆçD|UÄ)Ï‹øšˆD¼(âe¯ˆøºˆÓ"^ñšˆoˆø¦ˆ7Dœñ}?1.â}¿ð–€·\0%àª€iï	ø™€k®¸!àçn
+ø…€_
+¸%à¶€_	øµëÐåÄý\ø¹�ÑÍ»ûœX�®E¹èuÁ‡>ÙösÑïD8ð\ø4rð!.æQqÁ‹G�x‡¹Ûc¼«ºPƒA>ãÝ8ïjNÜ‹!eØ…õá	'îÃ.Žrp’‡å+HI8ƒã\<ÎÅ—¸ø²„â³\<-áG|ôM|WÂ�ñº„Ÿà)	?Åw$\À		ñE.ž‘p	OH¸Œ“ÞAFÂ»0%L`LÂ$Ç}€¬„�¸ö1	¿Á³~Ç£ü_�ð|NÂñ$´‚?áóþŒÏHø2K�²ÄõXvTK™Û�ËÉPèËôÇà Û±¬fŒmgXé­ŽQ�«�¤št
+ÑbfÓ�æ¨i$RÃd®Ì›3Ç’�-“MšQ�ã=ù�¬™HB)šÏPÍ„ž¢±2oõ~Kd°yÃÕíÔ”ŽžoæÞ÷zÛç;ìÎ
+iF�ÚÎA÷xs�„è¦q“Pš:jù¯÷ÎßeÉ�W”î_ÀNÚRÂ~—Sù½%öºð&7,çÕè6´´jhñ¨©š¯6¹T/ìbÕ©MÍŒ˜ê`R»sãE™o*a¿û¨‡ïÊû˜�oµYO¥(…9vå‹~Ç_z¥÷Pé=‰ÖIÄ‰ÿNKM©£u\VÇL˜ImvÈKóŽ#È:S‹ƒÃâ~F³ÎXepÇÉÑ¤|\324õ¶ªúº
+U;ø€Œ%©„IþB0?£#X˜Ð,šÏ˜™®<8ã'çLU¶«s€øÞ¬Ç5wËîhb4�Ôöñ•Õñ­ÒI	hu÷†»:å¶]�-‘pç¹'´¯/Üj!—�aè†<¬™&%CNÄºœ¡“1-ÍÓÆ¯�H"¥ufG5£—‘˜QòTQ¬R'¸b�2=
+EBÍ½²•ÿLü3öç³ ·ötuÈ”ÌÃù;+#÷·…zB9?9Ü){‹ð)ÊHËõ¸jªr$¼7$ï�«Ný?§—©òÌ\ò6ye<ªg�˜Öšàùmë‹îÚRdž8yNIó×´<Ë9˜Íh5i5“9¡ñíò¡ø`ÆÊþ#kú
+�Êš²Ê'ëC²jçö±nÝ:b�š#n©é´–Š3ØcI=C°Å¨RÄ¿¸6¤ÕZv3< Å³�l,3HÅ45ÕL5¦š�9Ëc¨ZÖAm³jöÑu@óiÇ²j’¨U¦�í¤Ëš4ïâ¡D*Þ’Ï4�-iœd„vAY"­CËdÔaKÔ™ýâÐb©›#QvDÍtè†Jj3‘Väîšåv‘µˆÇr�ÅÍIÊj§n¶êÙT|ž£)².)Xsë]vç%?Ç”_meé~.v,C—øœ‰{GýDî@®(qÄV/ü) ³:ÿ«MguÖÝ)ÚX\¡¢äç=¿˜¹?ÃƒGâƒ1E7ÔXRSÌ‘DJÙ™ÔcjrDÏ˜Jý¦†zÅÔ2ÕvT£zÙFÕÅ²¥´“dtñf¦˜”�ØÚ²»x«ks�ëø$uq#A7o]—ej±:D%=Ë]Ó¹Lmci:W{5v´—<h©‚eIRØ²4wrd
+ÌM=§ÒoÔÕô,‚ÈÝYýÔ£ÖN–—pg©WE-ÿ+wßs�Icø6I'á�µ„¾�,ôÃ‘ú¿‘Z>²Ô7‰Z{›}5$
+ŽnØH$e8pKHÿYDú¿Õøáè§åÌôkÉÊÃ	¾6�à…Ù0åÖºž²ÀÏäÀ‹¶ÑjàØ4ü“t:íL˜"2ÅÁ§ÿ6*üîUØr’ß½Œ”³Xã{›Ý+¦Ð¶ŠÍc³ÕL¡£ã¨²VÞ9à±Ùý3Ê†~ÞîdP\×è“´YÇ-�‹¬Û¡ÑîqÙ§°‹BWyN=.!§9¦q?­´Nqzœn×ª´O`£ÛFZ¿G¸�µ'G¸¥IÔ{²ºiü¡	tZ±XÂ"EG°˜P^ÔNC¨´ObƒÇi™"ý³›¨�Î}ä{ÛÄ(k×%ì±"¹y$ZëŽ|œ½µ¨«X7‹Rýrå¹D/
+à9ªêpáEªòKXŽ—±¯`NÓÿz©¼J•×èÝvõÄ��Ô*DÁfkÅy´Ó+$Bmoáa¼
+�Þ£TîãýIzo<MÏ�SôÚ8C��×é­ñ&¦Èz·0M�Ž÷ðw\Ã?q�ÑC�I¸É¼¸Íšð>kÁeÆ‡¬§iÅ±>|Ìtz’8ð!¾2C%;ñ“S©ÞwMx+/a«»’vÊÛ
+j/úÊ">[C‡ÏÞÐé+oPlL±ô<(M�Š}¢OhPìn�Ç^ë±]A«R>�ÕžòI4XŒœÇÃ%¡fMŠ8‰T?±]óôàìeÄ0‡Û™+¬{i®µ*RF©á¥‹É1�f…¨Øè‘¦b¸™ˆ¼rÛn Š—s^ÄËÉ£ºY‘7ùÐWóÜ'·h*Îš~ª>§Oû8äÏÂò\6j,ì­!uáq”]´¨°Œ­ £›£ÂUÔ‘¬£»�hP�J*ô*l¢ÿF¢ÀÂm¥Ç¨BOØ&zÁn#Ävl¦v+v’"ÙJ²…èÐ†>„q€´#ØK×F;²èÀØ‡gÑCd‹âyô¹úˆLûqý¸Nè› GçAü
+‡ð"Ò¿¨ý7Ðõñ(ñ[F_�A¶1¶q¶«%Û¢0Ã÷¬›ñÜPKkEÍûÂcPKÓ¥Í((edu/ucsb/nceas/metacat/DBTransform.class¥WûwÇ½‹%íZ¨„
 (�°vó06¶ÀäA„bÀ–ÉËÆ
 f-­m�¬»+ƒ“4
 m“Ò�¦M“¦äQÒ$m�´MËÓÆ¸%é+mÒ÷ó§¶¿åœœþ=½³’±lä“žVçhföû¾ùwîÌì~ðïk×Q�FüMÁœVðEg<­àÏ*øª‚ç<¯àk
@@ -129,7 +133,7 @@
 ¿AVàNÜJ»oc´~í„»•šÆí}~yWOàÞ	Ä'°k~>ïÒÅ;”ðºà@ú;T²_#…Üõ—±ÙË¢‹r\®†)<T�€Ë½¾8ð4Sà™Þ+zÞ!OÀ3…íî“«åx(ßJîq<R.¢ÍÉl13(xp÷²Ç1Ié!y&ýO#¹Ô¨œø|È33Á'4ž›&ÌŸ©Þ/a÷ÌN­,?µrþT÷yb´Ýè%üaŒáQö›ø9ò6û
 |ˆ�ØP~†ß@À!Jó2’D÷±K1Èµ!2f
 HÓÃQþ�Ñc†ÿD‘eƒÿcŒv}ä™Åñ(lÆÍ0ò(Ã	â$£?Ìu|ïSúOJ?dÌ�¸®ÿÂã’§¤9W‰ŸâÉâJ·3™Ù½UÝý:ªˆ‚)kýA•úŠæX½«9.uÐà
-x/â�ŽqÈõîæÿòÆ†õWÑr	„&±>ä¸ý¨—½»Ø»Š½GôÓ¨ê¸&ÞO€&q¿ä_4�U}äÃ$‚ s5&¢+…,Èw5p8��ã¨¸ÀÄWâ4Î`uÞ'¹-�g¹Ÿ#¤Ï“Ì/Ðâ,ÿ/Ñæen·WhqŽß´¯âsÜ=¯¡™Û÷.üýÜ5a~RFùEçe<ÄÏIøE‚z‰_& WðŸOÓïLâi\e¤)z»Fgñ&Á”Ädqþƒ[\aªÞ¿l}ã¶	lÞCvõ}Ó¨é¸'Ñ,MbSÈ3�»	^cHÈÄ.�§èk˜Ä†	D¦±Žº&bEš‡Är÷8‚Ï�<à¾ŠNòÒï%¶s8Û>ŽÊ€‹Øíp-Á^rg®Vr,Ú‹j¶ñ¿�ìk%4mØˆ¥QÚoãŒØ‡�ää.rn'¡ØFnÅYâfz:çœ}_ùPK¼ÛóPK&�Ì(/edu/ucsb/nceas/metacat/GenericXMLValidate.class�W‰_Çþ+Äb‚lÇ±cÇÂ�!9iRÇà¤ÅÛr$ Ø“ËY¤äJ»dµÂà6M“6ÍÕ¦GŽ¶i“º'=ÜÖŽ
+x/â�ŽqÈõîæÿòÆ†õWÑr	„&±>ä¸ý¨—½»Ø»Š½GôÓ¨ê¸&ÞO€&q¿ä_4�U}äÃ$‚ s5&¢+…,Èw5p8��ã¨¸ÀÄWâ4Î`uÞ'¹-�g¹Ÿ#¤Ï“Ì/Ðâ,ÿ/Ñæen·WhqŽß´¯âsÜ=¯¡™Û÷.üýÜ5a~RFùEçe<ÄÏIøE‚z‰_& WðŸOÓïLâi\e¤)z»Fgñ&Á”Ädqþƒ[\aªÞ¿l}ã¶	lÞCvõ}Ó¨é¸'Ñ,MbSÈ3�»	^cHÈÄ.�§èk˜Ä†	D¦±Žº&bEš‡Är÷8‚Ï�<à¾ŠNòÒï%¶s8Û>ŽÊ€‹Øíp-Á^rg®Vr,Ú‹j¶ñ¿�ìk%4mØˆ¥QÚoãŒØ‡�ää.rn'¡ØFnÅYâfz:çœ}_ùPK¼ÛóPKÓ¥Í(/edu/ucsb/nceas/metacat/GenericXMLValidate.class�W‰_Çþ+Äb‚lÇ±cÇÂ�!9iRÇà¤ÅÛr$ Ø“ËY¤äJ»dµÂà6M“6ÍÕ¦GŽ¶i“º'=ÜÖŽ
 Ä¦M·NÛ?ªí÷V+ý(‰[øéÍÌ›÷Þ|óÞ7£Ñ¿þ}í}Ô£ÿb&ˆl_âù ^	âµ Þâ§:ÞÒñoëxGÇ�tüRÇ¯tüZÇot\Ðñ[¿Óñ{u\Òñ®ŽË:®èXÑñ^M8BHÄf;D8BŽ†p;!lÂ±ÚDlqŽ5¡‹HŠH‰Û�Ì‡8ÝçD7ÚÄPÇ%À		zR‚Ž5c;ÆeÝSÒ›hÂ­x¤;ñ¨ˆÇdâq	ðD·à´¸=)øL™�‘–ÈYM	Š-˜�iÏÁáˆ(ˆpE,ø*^6ð¢ˆïŠøæ|g
 üóÎã~Œ¼�ŸàÛ~†œ�ŸÃ2ðé-bÖÀ’D^Æç
 \Å7
@@ -143,7 +147,7 @@
 ¸º«pur•2®{¹yà0q!®£œMÈÛ–oÊ‡™ $1¥hŸ Ç0öcý´­“g"¥`Ë°Võl÷­â¶‰ÎÜ�êº8.ýUl�Wp×*6ÉÄ�Ë¸gx¨däU¨™ÿÛ|$;	x�Ÿ×‰ä
 Î¼	yšöðeúµÚ	ê?!ççe‰+K™ÂZ’{ì¹�¼4Ë¸÷Ò~oýï`Ì¤¸||h½®ó=|–ð˜˜Oi|¢¶,ã“Ä®+�LV™„ë}mïÓðÖ®/¢1Ü˜ì¼XaTŒorT=éÚŽçYà¯‘„/ài;ÃþSÔ»xgñuzüçJ[Ðâô“ô]—²ÆVaL°ÈíKè)A~Pj'Ý«øL¼Åà
 È½�«x ŽÏñ)´—î‚•é\V^#a[&ba­¾>¬Õ0YÁž”D¿‚} Mz«ØAFE–°Ï×Ó¬s�ñR‚wV®NpCý…À2b/à Z½ö|…cÇØSÑ€“äÖ¥ŒÓâ?´;E�Gñ ãÌã=Áäœæost“ü)’aÕBÌ0â�ròp‘%y3—·UÜN>¶	
-÷®à)ÿ �ì•ŽI tL>n‡Og/±®=ÕyjóÞšåuâÐ¢À�K»-çx^ˆÿ¦ð43ô&íëði ×P=›IÞTl_þPK›XÍ‰gßPK&�Ì(;edu/ucsb/nceas/metacat/GenericXMLValidate$ErrorStorer.class•UmoE~Öqröå§¦mÒ–´¦MÁ±ã\�´€]ZÜ4I
+÷®à)ÿ �ì•ŽI tL>n‡Og/±®=ÕyjóÞšåuâÐ¢À�K»-çx^ˆÿ¦ð43ô&íëði ×P=›IÞTl_þPK›XÍ‰gßPKÓ¥Í(;edu/ucsb/nceas/metacat/GenericXMLValidate$ErrorStorer.class•UmoE~Öqröå§¦mÒ–´¦MÁ±ã\�´€]ZÜ4I
 ŽSì�ÞÊÚ^;W�ÏÑÝ¹¤‡o|©ZD©‘
 ŸZT�HH¼IÀ~bÖ¾¼46�FòììÌóÌÎÎNæÿ}ÿz�€À‹\àš‚·ä|¨àº‚�pE%
 "*R¥èÃsAøqJŠÓRŒJÇ	y^Š‚èET…†1)b*ú—Ú¸JŽ„OHˆ.Ág5\Ây)^Ó�ÆŒ†+RÌI‘CRÃ<^‘"¥á¼©a	/ixWŠ÷0©á})>ÀëÊ2JW5T1É†žèX†áPt,{ƒßäºÉ­ª>_¼!Jnj¯¹àÚ†UÝmn¸†©/¶n§Z¡ŽG3�¤Ë�JEHÌD4+Ê
@@ -153,69 +157,64 @@
 ·WÔ2T§þUn•Í­<÷¶1Ã‘îíº…Ýõ\Ã»;³òj+ú^5ívÓ1Œüg?3´E­~S¤MÓ{fÙ§¶p¼;Ó®Ï]5œÑ³T·ÞN’äcn[¤!B“P¡i¥Â‡°`¤gÑþ£‰G2@–Kx•ä´KÎGk(¶�±ø=œˆ±{º9ò2$�Ñ€nÓ\¡Ð·i7B÷S�Î°€^ 3ô	��‚±øg8¸�gwB¨-Çwtò·dY$Š¯“îBù�(ßcŠ4?Ùûé·Œ—½ó&h¥¹Œ�Øçz„^vG*w¶#PpàãÊ÷K²®àœÇñ¸½ORúZÆ&MŸú	¥ÐKke�•
 äáž&Ž,%âMmâðR"ìÛÚ“J;��Ø&‚„Q-YÒ¿‰¾rœ ÐqI¤ßp˜%š8¹�Á¤_rŽú›8´S€•ø‰Nÿ!ü‚aüŠ“ø
 QüŽ$þ üþ¤¯Õ_ø‘ç½|uïj!ó!T¹41rwO]Q]¾"ý!YW»¿á3]äÊçkÒÞ"Ý‡iÌ¶<ôMtøPK°#t‘
-PK&�Ì(:edu/ucsb/nceas/metacat/GenericXMLValidate$ParseError.class•RËnÚP=—Ç5vœ„�Ð„¶Iú )˜$N;ªnPS¡’¤UÔíÅ\À)É6•òO]´R­J]ôúQUçŠ�ñ"eqŽgæÜ™Ãhþüýõiã¥†
+PKÓ¥Í(:edu/ucsb/nceas/metacat/GenericXMLValidate$ParseError.class•RËnÚP=—Ç5vœ„�Ð„¶Iú )˜$N;ªnPS¡’¤UÔíÅ\À)É6•òO]´R­J]ôúQUçŠ�ñ"eqŽgæÜ™Ãhþüýõiã¥†
 ‡Ž
 ŠWt¤`*XU°¦`]A^Á†‰M”ñÀÄ3<2q‚}¶
 OUø»éJµÉ°U©¶®Åa…×·/;×Ò	ëñt;ô]¯_Ÿ¾¹bèUZ²;±'NÐ±=GŠÀÉP8"´ßIOú®óé¼u%†nW„²¾Ü¦Ù\ž¸¬RƒŠ•ä<íznø†!Ów%ÃöòÜõ��Ñ_4›UC2`¨ý‡y†õ–ëÉ‹É¨#ý�¢3¤a…¤}’¶e|~ ßúþØ§ =žøŽ<sU½}ã…ºœ�ð/{½@†Õ;{cxugmyÑH®G.Äˆ:¬öeØX˜¾BñÙm•Sô^Þ�[ú˜®a<Kž}†||tŸ•šçÒôHéx0ÀÃ�”éþèBÓ8
 êÁð³�ê”éP§\ž3]ï”O§u�^ìàa‰¢uÓˆ­ŸÈXµ†u�[»rV1!k•²4«Ä#èßIÉ°GhÁ Ï2ä KÌ‰uÆ±Æ4l²JLÇ>3p@5†
 y�ÍS~qÖú�ì×Ûv\%™U±• åßbÒ<¡…Í©—*Q-Ñ@.n`ƒð(Ñ€ïªDÏ±=—îÑSª¦V¸°¦™¶Hµ'¥p‰
-Êªµ<þPK`qQŠ0¡PK&�Ì(+edu/ucsb/nceas/metacat/MetaCatServlet.class­Y	|TÕÕ?g2™÷fòØ†°%d–
-8–@(â$ó’NfÂÌëR­UÜ¥n€K­­�Õº`5!FQqomëÖVÅZµjµîUk+ßÿ¼÷&™!‰ØïûÈï�»œsÏ½÷ìwxê›û¢*´�Ry’ÊÇ¨|¬Ê“UÎUyŠÊy*¯Sy½Ê'©|²ÊT>Eå�*Ÿªr@åZ•ëTª\¯r£Ê!•7©|šÊa•›TŽ¨U¹YåÍ*ÇTŽ«œP¹Eå-*Ÿ§ò�T>_åT¾På‹T¾DåËT¾Rå«U¾Få�*_§òõ*ß¦ò¯TîVù•Sù*®ò×*ÿ[åÿ¨6VmŠjSU›Kµiªm�j¢Ú†«¶lÕ6Bµ�Tøb…oPøF…¢ðM
-ÿTá›þ™Â?Wøq…ŸPøI…ŸRøi…ŸQøY…£ðo~Náß)ü{…ÿ ðó
+Êªµ<þPK`qQŠ0¡PKÓ¥Í(+edu/ucsb/nceas/metacat/MetaCatServlet.class­Z	|TÕÕ?g2™÷2y2„eX‡¨²
+Kv¨–@– \p’yI'3a –ºÕVQ‹u«×6.uÁjFÅªà^«ÕZ­¶E«U«U¬uÃåûŸ÷ÞLfH"öû>ó{ç.çÜsï=ûyòëû¤,*³�Qy’ÊE*OV¹Xå•KU.Sùd•OQy­Ê§ªìW¹AåF•*ë*7©Ü¬r‹ÊëT©ÜªrXåˆÊm*¯W9ªrLå¸Ê	•7¨¼QåM*·«|ºÊç«¼EåT¾PåŸ©¼UåŸ«|©ÊWªÜ¡òv•¯QùZ•¯Sùz•ïTy§Ê©ü[•ŸTùß*¡ÚHµ±j³©6‡jÓTÛ Õ6Xµå«6—j+Pm#U›[µ�Rm£¾Xá¾Qá›þ¥Â¿R¸Sá›¾Eá§~Fáß)ü¬Â¿Wø9…ŸWø
 ¿ ð‹
-¿¤ðË
-ÿQá?)üg…_QøU…_Sø Â¯+ü…ßPø¯
-¿©ð[
-¿­ð‡
-¤ðÇ
-¢ð§.Ú@/¸¨A@T@³€¸€µô¢‹VÐK.*§—]TEtÑjklpª€ýÉEKèÏ.Z*`™€
-zEH^ðšp9è¢Ut0‹t:è¤Jz]À_¼!à¯Þð–€·]t2ýMÀ;N:…ÞuÑIô^ÕÒßû¾œåÙírð]¢�\TFË1>qÑFú4‹šè3Ÿ»ÀàŸ²ïÂåË,:�¾Ê¢:úWEèkøý[À\ÔHßHï“`Ë¢zÎpÑ&¶c7ÎÄ©Ø°.¬
-Öé¢åìÂÑ8ÇeMzƒ²(Àƒ]´™‡¸¨š‡âúâ<L¸¸…d8äÂÙ83��áHH�GáT<We�‹b<Fv!òQ,�ºñB7A^­ç‰Â9GGg’ùoP²3Vc�¿'`®€yæ¨°R@µ€�/åbe_.+®àh¼�ÏÒøÇ|ŽÆWñé_Ígj|�€]Üªñ-\©ñ/¸Tãv>Cã[y±Æ¿äã4¾MHn—Þ¼Lã;y�Æwq¹ÆwóT�w³_ã{¤÷kž®ñ½¼\ãûx‰Æ<MãNöi¼‡ghÜÅ35¾Ÿ5~�OÔø!{y‘ÆûxµÆËp¿€G<*»àUÿM˜¾Ãù¿Ë¿'ˆ¿s‘Æïó
-�?à³5þLŽû¹òŸ¼Tã/ø�¿‘|Åk4þ/ÔønÓø¸Øˆçh6±Í†3Û2@g³óñš-“×j6ÏÖlNAdq•fÓ„n0äbÊ%šm˜0pó,Í–Íg2“ê*ö5Çôy.&�ka,�yCoLO´Ä"¡Hƒ·>Ö�c/“æõ£u-Mz$1�É‰áæ=Ö†¾Í›Ë”‘;¥Ì€K™FåN)ßØð…¢¾ªX(’¨‰…zlSvD|Ëk7éu	L�H›^ÙI„šô>äÕ	ðjÀôÈät|sØ·R�·„Õºðñ$-‰PØ·0‚ÓÆ‰P4œ×ÂµúâzlKXOøªÍ¶$Iè­²§_cÀõr¤²~÷¶c~�¡¬|fnÙR!˜š»tJ¹lñµÔÅk}‘:=÷5é‰@] á+]°RõØ¤Òh]¢­Y/‹ÔG
-),í—åØþæ´Ô×"µçû
-Ëíù"hmŽÌ�ÎíW
-‚ZÝ?*EzKñÆD ¬[c"Ñì[`É
-hŽFâæ–¹½|Í;ÎéÕ�¾EBzln_Sè×:ŽDØ#¨ýB—³û™ÿßìmmÔ/áä#VÅ¢uz<þXö\§à;öÂÔ�ÉEúU1½9ÓƒÕ‰@B/Æ’)/9Ì˜ŠŽ@3ˆ¶Äêô-‘ ±`DÖ0¿~	žÔŸ`*û¡üî3ýxÃÆÿÃžbîL¬"p Õ+Ëç¤�R�µOñæ¹êC¦PWNÒ×K®ã‰ÿÊ™#¹åÑX .¬ûZ›Â>XVù¶L÷­­.¯N´…õx£®'z¥šæð=W€EEy©•MÅ
-½ö�5¤q²Ê ïOÊk$î­—†§0
--ôùjf”ø|KVU”û|Q/ÙŠZ´1
-.öÕFƒmóŠq×¦0ÒUV±/%‘©Å¾dÓŠ}1#™ÄuÁŒ,>ñnÑcq(bnÎ´¢©9'HªY,½uá@<>7Go
-Ë0+V7BóŠÃ¡ÈiÈ¢á¹9ñ1åx%ÒÏÍ‘Tã«‹Çs¼�1½~nŽ\6
-ÖúbÑ­uÑp‘�òÉi…“£Ø:¶£8	%Œcöž§±—Dƒ:S^¯ÍxQo0¿
-Äuo8Oy½+õh³.9½¨¨ˆiœ™ë§J¢O
-Ä_Ü,<-üô#àg„kâôD"ë-+õ£”p§cCA™=pù1ÑDYè½Z]Ï�¡“&Ö1hšÍh;±ç¨‰X ¯�ÆšÒNæcLü–@8Æ©Ø¢®[C‰F9®i}rÚìtÌ4!ÓÃR¦#P´ÌÍ6æüÞ€©›H4�6„âˆ=zš©
-ërDçh,áM4†â^]V`{×ÂÖ:½Y–Å!…#U’Z¦©55‡õbê œ40áª¤¤@6¤<Ñ+[šjõØ*IÞé1ÑBéî7sRÒòb³K´õIã¾5æ1�?R57¼w*	$,D‘�3
-ZBcVå·ª
-$çBOC6^3¡{ËàkÞú0EL«^X¾°d•˜†¬ò.Z¹¼ÂÇÝ˜´•¸·fÉÂ•… ôÎõž‰Xû¬B0¯Ó±›«Ú¸¤ThHx«u|sKÂ‹pè…â+—¯ò®™_^VZ\Cp[Åù¨>”Ì{x¿	Ò°ÜÂh†×á^è„CuF1ìÃ-ôDaÜÐ*Ö:Ä‘D�!ZDq,&¥Î%zâr¸jã`-ÆÎ ^@*]±úBÒQ‚_0ºX•#­Bð1& Y­‹¦*,åÂ|<,±H,±È°Ä"Ë“-Rçìž)ÿ¿¨³aûßÅG`¤Gö�o;›Y] ¥
-@±X�è±PÔ¹Æ=ÐÀ1Ð¦òÀG³èVÃ¯�Ø ÷xMH4â@î„C2Y _½U‡.iZdßAV/^5‹æôVÄ'Ð–\—Â1�ˆbé úP$˜LÜÂ°AÎã4ýžê\ƒ{¦ì[�ÀhvHñ_�U¢Cwê$Ó"“Y2iÅ	ä¿£L1}&KëÅh²LæéLÏ0ûIÍÈÂÃ–-’ÎŒüÕ�ÛÀŒKA�¼ï|Ë©FõbÃéÁ˜a$m&fzƒµºª¥Ïêa&Æ°¿ä\¶9—´‘”�âÑ˜¾0¬[š°K™€FŠÈ(õ-ˆ=S‡eGª-çžÄ”-ïI6)³)AþðÙ¤³“³¦Œ“>éí
-K%R(UF‹¢°‘>»$)³ƒ{gË£¢³ñ½•-ápU›ë±”Ãú¼²ÒæzŒcèá‘	¾ÿ×T:mruSÚqW5¢Z3¢–Zí&‰Ò3ŠŒ�_a0ù¾?e uöLV¯(O¹k/q
-‡ýþæ‘<LúK.©™oI¾È=ë˜ŽJÏºVë	Mc¿%i[ªìƒM¹ÞQýXoÔ Í7Kþ‡?nà§ém°GX�4Hdt†abF˜.b„‹,i,¿‚HÕYº U™J4Y’M0Ÿ6E›‚µuEÁXO…¢åÆT©1À�ú}üTÏ_k>mpá�^G•FUßÿz “ë'ô@³<A‚vÎ‘qˆäÑ@µ®º5C¶ÚlšjŠ�e6‹ãCF†,\V¡
-f`Ñ,,²{#©²Y¥¤ñÌÍf^U�6Z»	—jÁLš”!b€ùÂ1Îg¸•f>
-ŒRZòRÜŠï‘Ä*#Ñ(˜0£Å0ô¬h	%URtÆ[jãÉ`<ÀÌ`©ýV³íÉ‰ÞüžÝÓO;Ÿ½Å¾º¥'uNv“\LXÕÓ±¯åõèm
-„±2s«DOˆÌØ|0 òw m¨7âµ½µ9*1½
-
-M¤JŠÑ`²ÉïàèÙäWpùA]~7Úo¸Íhwq«Ñ^Å§K+¿ãÏ­öj³•_��6Ûš¿Æjo³Úøl4YÄòƒ=`F?!1Úey�´5�ï£K\&àRûüXÀåžÐ%à
-�xNÀv;tî–½øû€h(à|²S	9©—]HÃi�¦Å4Ž–P•ÑdZJ´Œ¦Q9Í¤
-šÁœHËAYÌ|Üê‡<Ç<,·�ƒTp|–ýö¼{éR÷±]t¿�*íÝ´vÝ„N:½ƒ~ÝEìTØE×2Õ ù“?Ó“ÙE÷2ÍtŒpì¤MžL{ýÂF~{;mð+÷ÐžnÚ°Îíí¤x”úImë ';è�všçw$Ñ9‚v¤£'ø3“è‰‚ÎLEcó‹™ÒˆÆô!òØï†xæAË(HSiþ‚”Kâ/Ht;Ý‰Öç�øvÊà;ðÝE
-ßMN´ƒùNÂ¿¦‰�~.wàë¤©¼_Ï÷Ó<îÆ÷-A»Œ¤
-~ˆÐßÄS˜÷Óù ½�Åi£[øqºüïä'èn~’žâg°ûµ¼Š{9gÊ@«äåtÒí½ºvÁ�ˆÎ„†Úx+zŒÃ´Øßuñ�°èœ´Å6ùSù¶%”	:âK2fÚÝìÏ,ptÐuûh±ßQèÎï¢Çl›Ø~€›¤qÏØC7wÐ•»È›'¢—¹=ô,äoaDþ0Û¤f&#4@xÓ{ôƒ¹h;û•nª.;:éL¿êQ;hçN:Æb½ÃbmO[îWÚiJúæBdBCLï�=ôsi¯ñ;=ÎúMM;�¬Î=8;î=ÎŸÙNr”t¾½¼äx8ëŠu¥“¾ïWÛÉ™?¼~+G~xÝL§í¦CKÿÂv*ñ«Éû�&jªeb;Áx2­»eÈ‘{)Œƒì†ž^¡÷éCªá£y	/£K£»èXèêØé‹°Ó—ÉÍ¯Ò~
-6zö÷:5ñ_(ÁoÐVþ+�ÇoÒ%üìîMØÝßèy~—^á÷ðý�Þæ÷é}ô?äÐGü!}ÉÑ×ü1â÷ØÆŸb×Ïð}ÎEüOã/yÚþ
-gùŒ—ñ¿¹‚ÿÃ
-ˆ¤›øoÃÜÅü<¬ê!X•a’|¬iUÔ��âœ•	=¸}¦]eL÷qÅcï¤³XfeBÞ?	÷Ý/š�ZSèžk˜]¾!A�HPôê†·	Ùn5)ÍÜþ®°wI]µ“²ÝóL¢õÛiP3
-Ôä$÷ä¦7vÐ
-~'F—{�ÓíÌï §v#v;ÉGÓi�%÷54·*„Ü‹ÈÁ>Ä‡©ø¦ÓHžA“x&ù0žÎ³hÏ¦9|<mä¹ˆóh$rÏ‡.æÑ¼_J;y1µóRº�ó¯Tá¼kà•AÈn_Ò©3fÂ[aÏ7$"?N'ßCW»Gˆç¸gaæ
-|OãëÚC’Rºi©˜í¥�tž$—nZb
-(iñÉþ	§�†Ô·£ŒX›QÐ…ÓP%ïw<H'ûÝÔ°®“¶øøÿMô°öõµ'¦}ÀÛó=ˆô?µI°»³vR\ÅcÏMÝ“ì 'ª=ŠÛ'�}o�{‘ßB—A¨¸b¤xì°÷ÖÛ»˜vºôy=ºt:g¹#QÜ‹’“–¹¸Fº²éwWÝ@.÷q~g;}ÏßHÃ¥ó1_cÍñ�Ÿ ã,„74ö¨yŽaƒó
-=
-BæíÔ†ÉãŒÉ<kò—íôk…ÍðMÑš´Ñ,8>�Ë¯Úi&ç§MÞÙNã1ù½´É[=
-ÝGƒOa]´™j­ Uðò¯¸’WÀë7sŸAkŒö¢d¦âä3¢ËI¡+°b;¾+Q
-\EnºšÆ£?‰®¥´ÂNðÛŽ×Ñjºž6 *ý”èçÈƒ·Pý‚âH¡gÐ­tý’. Û°úvºY±�î¢=´›öÓ=t€î¥çè>zžºè5Ð½C{éŸ0�¯èa|ûy=Êcè1�v"€/<8À~z‚KèIØù°ó§¹’Æ­žå•ô;>™~ÏA´
-ôÞŒ˜´™^@=ö<nû"ê³—øô/¢—ùú#_�þú3ßŒ˜uÚ;èUäà×x/Úýt9ôuÄ�ƒü½�8ø6bßÅ‡å¹‡“yŽ¾†”¥È¹¼À=ÕJpC«†Ä²ÎògvS9¢²é&gøíTû7BÐÈÃ+¨ßŸDŽê9.‰ÝÙ™ì’ZÜ
-ç�j-J–v1Ž-m!!¥Úã5”Å54š×ã;‰&£Íƒ(x•¢¿˜O¡2ÞHôƒ|*ÕsaGG	Ò@—±bR|¡YË2x|�8‚årrõ}h˜4â›»¤Žså»�‘SÊm:©Åï`„Y‡{(îSƒ6Ûl�»:¬"l›{pò¶À!ì¯›åqZñc­_œ_1ö=Y¸«3­D¹Í=(eµÓ
-�a¯!2“ï]—ïGõJÕ‘ÔAX3ä“!ŸýYÝ”@Š?U¢á#�¨Š:é\¿ÖMq\®Í£öà0²ýY(øògy²�ºÛÉë×L�Ž—sjéêÎ�|ñ¢yazž¦� Ü�¡¾Oh}Š²ü:†>§|Øb¢ã8ƒf³�Nd5¤
-Å9é4vQ„³ètÖ ¼At3Æ¿â!¨²‡Á‡Üð%„4pÃîGÒ»<š>†~ÆcñÅNÇnÏÐNÌã±\È^öñD^ŒþRúÆðH�1ì³¼âKÃôfèvª«A>pÎr¤&îL#&gZ‘ØaäP‡$nÐÏè/qgö$nGzâ6Ê­fˆ½Už°’Ç»©Âô¿ç:é|¿ÃãÛyf¦ÒÃÕ=ëòÝn¡ì$-ß=Å`ç5wÍµž�ÊÆ¶žíòÝšAåî=¤{‚å~ÐÐphnH%ÈøçÒ[ˆtÉÌ#œ‘¥28†/NCÑçeó…h3¯È1xANõqˆ`'b\‚a)^Ÿåxy®ásQ•�CÍ˜�óùt"Ü¹¼
-ß…¨.¢]|)´|ÝÊ—£JÛM_I]|íE»Ÿ¯¡gøZhûhû:zëÞáë¡õ¡õ›èŽà”x•Uu�×–‡Àyù�tw^¾<;‘ÂoaÄðË¤Þ�lÓöÐõû¨oÊ<ˆ»Ó}bÝ_”g¨1ž�w™ãÂäø
-s\œ?bŽK“ãçÌqQr¼ÝOOŽwü/î”âÅQQ°WŠåô'z*$zaKu1:Ê(Ý˜LZ‹‚teÓzÌnÀSðšM‘PO&@�TK­TGÛywP=¾F$Ñè&¤ÄFº\@â|š"Ø«»5#%n¦·ÑÉô=J `_m¤;Â�œa›ñëÁ¹ÿPKN”÷OÀ
-+PK&�Ì((edu/ucsb/nceas/metacat/MetaCatUtil.class�“[OAÇÿÓ»­-”
+ÿQá—þ“Â/+üŠÂVøU…_Sø/
+ÿUá¿)¼_á×~Cá¿+ü¦Âo)ü…ßVø…ßUøŸ
+¬ðþDáOþÌI§ÐKNjÐ&`½€¸€Õô''­ —�TC¯8i9ýÙI«¬pŠ¿€½ê¤*zÍIKT¨¥¿É_üM¸ìwÒñ´?—šh-¥×¼!àïÞð–€xÛI'Ó;ÞÍ¡µôO'�DïåR#½/ØÉY>�Ý>p@Nÿ‘“ÖÑ¿�´˜>–³üÇI§Ò'¹¦Oà–késÙüau0—Bôe.è«\ŠÐ×N0ý€ÉIAféÙd	°ÈÎ¥fv8é4V°«8ç@ìÎ¬æ¤e<çã<œ™KoH.5p¾“¢ìrÒJ
+ˆs�p&$Ã!�3óHº!:…SñhÜ—Ç8)Æce·q�$�‡tÙ#t„®PG8éD>R8%ˆ‰Ùdþ7(Ù­q�g
+8VÀq*,°J@½€5¾„�P­ñe²âr>Wã+ø�Á?ÑxŸ¡qŸ­ñv;x³Æ·òr�oã…ÿšÏÒøv^¬ñ|´Æw
+É]Ò»›kÔiüž¯ñ=¼Tã{yºÆ]<[ãnéíâïk¼›Wh|/Ñ¸‡¿§ñý<Mãx†Æò4ÞÃS4~˜çiüˆ€G¹Jã½¼Zã}2|LÀãž�-Ÿâ4~O˜¾Ïåÿ‹½ ˆyªÆøx�?âkü¹œù9éA®ÑøKž«ñW"—¯y�Æßð"Í–Å?Òlvp±eóÍæ±MÁ™m*èl9\¡Ùœ|’fËåYš-OCx¥fËº¡Žm/ÐlÃ…Áöi67ŸÍDLª³ÂÛÕç8™ÜÎùÑh$ê	†=Q=žˆ†ƒáfOS0¤Ç&Íã©D­z8>‡)Ãõ	=ÚŽ¾ÍSÄ”U4¹Ê€‹™FM®^çßà÷#ÞeÑ`8^
+Æõè,¦‚$&ä7{—6¬Óã˜–1½"Ž[õ>äuqðjÆôðätl}È»B�%Bñ:]ø¸“ˆD<òÎã´Q<	ç±p›¼1=º!¤Ç½uf;/Žë›d9N¿Ê€käHUýîmÇü*9BUÿøì¢ªÅB0¥hñäj=�ð&c
+Þp£î�y[õ¸¿Ñ÷VÎ]¡ûzôÈÊHc¼½M¯
+7E),î—åèþæç&šš‘Ú‹Œýò‹R"_­Í’¹‘EýªAPÇ÷�J“Þ"¬%îo«CÄÖ�·yXòƒÚ"á˜¹eQ/_óŽ³z5A‡¡oQ‡�N,êk
+ýZÇáS‚Ö!tyt?óÿ›½­�ú%œtÂeÑH£‹}–©ë”~'Â”!L˜\¤¿,ª·ù£z .î�ëâÅX2yà%‡ØSùaha‘D´QŸ›ŒÃú[°j€ù5HðÄþ3«Êï~‘Úï´z ™~|iíÿ‰áêJs¦ñÖa¸ßñ+ªgeŽÒ]½?ó
+÷š‚¦JVJÒ×Çìcñÿ*„‹ª#QcH÷nj
+ya{XåÝ0Í{B]u]¼=¤ÇZt=Þ+ÕŒp‘ºÚ,jª+­\´ êoîµæH´Ù �á�Ëòþ¤¼J¢æix2Ó�2¯·~ú<¯wÑÊšj¯w~-2Zù&íLyÞ†H }NîÚB²Ë­ð¦¥AµÂ›Ì‚Z…7j¤¢˜.˜áÇà ž
+z4EÌ.œZ>¥ðI´Ã+„¡§1ä�Åfê­!bÅòŠˆ`NE(>
+984»0–S¡GòÄìBITÞÆX¬ÐÓÕ›fÊeã‘@ƒ7ÙØ	•(¯œVX19*¬c;*‚á`Ü8fï)qû¼H@g*îµO<â	øá,þ˜î	Ebñr�g…iÓ¥"(//gkV
+S�õ¤LH
+ÄWÑ&<-ü´Ãà§„mâ›õx<ë©ªô¡qebƒ™9pñ2ÁDYè½ZcêÆÐ‰IM„
+š63VOH5õ‡cM‘hkÆiÁ|”‰ßàÁ8[žâº1o‘ãšÖ'§-ÈDÀLã2�Ÿ6†¢eîhcÎçñ›º	Gâ¸as0†Ø£ ™e!].ƒØ‰Æ=ñ–`Ì£Ë
+lïœ¿©Qo“e1Hápµˆ$¦�iê‚­m!}¹˜:�˜peRR \ëµ‰Ö=ºRb/Bf…Dt¿PºúÍæÃÂ´¸Ž¬Ú¦Gãí}’ÏØo�yLãW­Á�æùã¢\È™-
+ 1«nƒ[-óÇ[fCOnC6³ðTÁ×<M~`Š˜Z7¿zþ¼•b²Ê³`ÅÒwmÒVbžúEóWÌ‚`À3Ûs$bík°
+Â¼NÇnÎ:ã’Rß!]®lÑaðm‰¸áÐÅ×.]éYu\uUeECAÀYa•ö#úPT0ï¡ý¦W‡ßr‡¿
+^€{¡
+6¥´·Ðãe1Cw¨w#D�†hQÄ±˜”FS”è‰Ëáj¨¬
+çô&?"På\˜ˆÕ’6ˆü‘…:¨�È2cR‘e‘Æ¨aªÂRa2Oªbl²\l²Ü°ÉrË&“-’èa<€©ä¿¨×áßÅ[`®‡÷•o;›Yg ¹
+@±PëÑ`#»ÊBÅQÐfšôÀG³èŽ‡‡!ÅÁbõAÑ�U€?„h’…Më›thU‘&!û²z±Æh°Mt¨oB¤}žÄâò˜ þxK5Ã�d
+†Írž@Óƒaëén–×;0e/Ø„h3°ù Ùûq|=Z‹]és�LB&seÒŠÈ„ÍFÁb>M–ÖËÓd™ÌÓ™>bö“š‘…)—-’n�LÖâ—ÛÀ +A�¼ïq–{�èÅ‚œÂ˜%c&jú…µzY¢Ïê|cØ_r®ÀœKÚHÚF±šHTŸÒ-MØ¥`@#åd”þ¦ÄžéÃ*‰(uVšÄT-M¥�´Ù´pèlRŒÉYSÆIŸôô¨yR2ÕFâ"°‘>»$i³y½³ÕÑÙ¸Þ‰ÚD(´,‚ÍõhÚŠü>¯µŒ¹”q94f"Õ÷ÿ*Ë¤mGÖnÍ8îÊÔmfjÔÒëÞ$QfîC¹1ðk&ß÷'$ÑÔdÝòê´»ö§qÖïo'ÉÃd>¤’šù–4Œ¼1Ðó�iLfþµÂX*4�þ–ôm©²6ízcú%°^1¨@›¯—>ü}æÀ=NÓÛaŽ�n–È˜‚‰a¸°.r¥±ü
+v õgåÜte*‘dq6Þ|ä”¯44–¢A<Ê—S•Æê÷TwÜ	æ#è�TkÔ÷ý¯:¹~Â@O5Ë$hþ9‡HIªmpÕ�‘(òö�6ÓTÓì,»M0Údá´Jn0‹6a‘ØI•õ’(%�g¯7óªj´‘†u�¸ÔfÒ¤=
+Ì·Žq>Ã­4óy`Õ’—bV|ÇW‰FÁ„-òÑ³¢%”TcH1'–hˆ%3€ñ3ƒ¥jô7™ÝH*GÄ{ó{AªŸq>{Â¾º!•ºó’Ý$V©³AìkizýADA¬ÌÞ(Ñ"36ÏDþö‡"ÍMF¼¶oj‹HLoGCh)µQÙäGuôlò“ºü:/¿¯K+?4ã¼Ùh·ñÆ|>ŸmŒ¿°Ú³•_¢�ÖmÍo·Ú;­ö#þ1š\bùõð4Œ®%1Ú%ÅÝ´©˜ï¥Ÿ	¸XÀV¸LÀÏ<# GÀ%ö
+x^À¥:ìÞ){ñ™€siˆíTI94—]@Ci!�¤E4–ª¨�Ó$ZB¥TMS©†fP-Í‚`Ž¥å ®v.ÄrÏ1Ë	r�
+ŽÏ°Ï^|muMÜM÷Û¨¶ÌÞC«W�ï¦vÑ½»éq;•í¦mLõh~ÉäËvgï¦.¦ŽaŽZçÎ¶ï¦›mä³wÒÉ>ånº¯‡NYíòtÓÙn¥‹®ï¢-]ôT=ØIs|Ž$ºPÐŽLôx_v=AÐÙéhl~SÑ¨>Dnû]Ïd	é4…ÖáO§"Ú‚?�²è6º­)Î
+ñ.ÊâûðÝO
+?@9hó¸‡óC4�¦"~ß£4…÷âÛG?àÇh?Žï	Z„v	?I5ü5£¿ŽG!~–~
+Ú-ü]ÈÏC\/Ðmà¿HwñéI~»_Å«¡±—#p¦,´JqIi7ÝÞ«k'‰èlhèGüCô·B‡ÌW×Å[°è'‹mòÿwLåÛQ6èˆ/Êšaw±/»ÔUÚE×<D‹|Ž2WÉnzÌF°‰K÷q«4®ïí¢›ºèòíä)ÑËÜ.zò·0"˜mR3G#4@¸YÓRúÁ\Ç>º„}J-.Ýt†Ou«]´½ƒŽ²XwX¬íË}J'MÎÜ\h�ìCˆcˆé=¸‹~%í•¾wNý¾¾“†×çœ÷ëËî¤,9J&ß^^r<œuÅj·ÒM›}j'å”¯çäÈ�¬ž‘c»î›Ò¿ “æùÔäýG5Ý2±�`ÜÙÖÝ²äÈ½ÆAvBO¯Ò{ô�ÀGð"^B'XÝN¡«×a§oÀNß$¿K£øŸ°Ñ÷`ïS+ÿ‹âümäé\>Oùvwv÷1½ÀŸÐ«ü)¾Ïè-þœÞCÿ>Hò—ôEùkú†?eB×6Ægãr›�§Ú²y&Úyˆ„‹0¿Ä–Ã56'7Ûry�Mãó1w!ï‡U=«2L’'šV…èà³çÌÌ†žK]^Ó®²¦ùŒ¸â¶wÓY,3³!ïË†Ã}ÍN©/sÍ1Ì®Ä� [$(zuA�[„ì|—š”æžR×¬WX�«²‹®è ‚2×1&ÑúžNš
+ÔL5)É=¹éu]t­/£Ÿ»wŽ+§¤‹žÞ‰Ø�C^šFk,¹¯¢a¸•rŸE®@|˜�ïÎÇÒ‘¸µãi\IÓy>Íâ´–#,¡
+\Cgp-t±„Îã¥°øåÔÁ+©“ëé^žix¥
+ç­‡Wê�ÝÞ¤SgÍ€·]KD~ŒNº›~á&žã:3—à{_Ï.Ú%)¥‡–ˆÙní¦ŸHré¡*kx®¤™ª¶†?EÂé¤ÁõÂmŒk³JwÓ-LµP¼ßñB·£‡ZVwÓFŸÿ¿�Ö¾Æ­î¦n¦‡€·—¸éo´I°»r:¨®â¶g‰¦îÉtÑ“unÅå•ÀþÛz×BŸ„NƒPq-ÀHqÛ%`ÿ¶^ØîdÚþÍ
+ /Né2'g¦Ó0Åµ09i™‹s¸³€þpù5ätÍðåtÒ÷Ìñ*�
+Ä\AŒ6Ç;0>VÆ¹ohìõPs…ayÅen!óÎNjÇäc²Øš¼­“>­Ì­¾	#Z•1Z„¾.wtÒtLÎÍ˜¼«“Æaòû“·"z”¹ŽŸ².ºp'2Õ`¤æ•ðòÏ¹r¯çvT'õF{A2Sq!òÑe¤ÐåXq¾+Q
+l#uÐ8ô�¤«h:]�ô~
+ø]Ž×Òñt�Œþ©ôKj¦›‘oA¸•bÈ�›é×t.ÝNç!^FwbÕÝH¬¿¡]#¢.Ú‡Þïi7½@Ð_@÷6=BŸÐ£ô9íÅ·�óéqEOð8´�Ó¦ÓS¨€ž„Ÿ<
+Ÿx†¢]LÏÂþ÷âVÏñ
+z‘O¢?rm3½ÄëéOø^æv´›éÔaæóÐ¿1ê"z�¯@ý•o ¿ñ­ho§ýÜM¯ó´Óü4ýyõ
+~	ñì5z1èâCòÜ¾dž£ƒ�²9—º¦X	ahÂ�XÖ™¾ìªAT6ÝäG>G'ÕÃþ�4üÐ
+ê÷%‘#úAŽM"GöAöF&»¤–=;áü#Q­CÉÒ.Ä±¥
+ $¤U{ÜH¹ÛHˆm$·Ð$´Å¤R^G•è/Ä«8D~ôÜJMFØ‰¢‰ÓV^A<–JøËšƒãYðøRqËå�ù§&3?âµÛ±�†¤¦€W š‡÷ÑD·²�†Jß�-W»ZÊ½‘æ¸‹®’‘³Äu”\MDÐM|*ûœÀC ø»«Àl
+9¬Êm‹+/)"àD~ãËí¤™î\+è¬Fæ¶Kî¾F�ÓZ�-«�²zPÚê\+¢ìÅ^ƒe&=IhnÍJ#zU¡&ÖÌ�dž`ß J .ðKÝÛMçÀìËë¡8.wº;Ï0"Õ(Îä.zÈ7È=Iä�NòøòL3'çÌË´$yæÉ¼–RÉ½‹Ê?†Eü:ÿ„FÓ§pëÏPß}Žö Í¤/©‚¾B…ÿ%*ûo`!i
+ÛèTV¡y
+…çù”àT‹Ã�h†Óu<‚nä‘t'»©ÎúÆûy½§ý„Ç3ñV¹�óÑ/@±1Ž�â‰<	'+Â7™çp1/ä^‰v5—â¼EÜÀeàrÞŒþ™tÖõxÒºP.›nö™a]ózS~'5Ö#ÁäÌt¤WÙF�Ï¶B»ÃHÊ©@?½¿J ;U	82+£~[•´Ë»ôDÕšý|7�çs¸bW¿›¡¤¸º†b]‰ËeÀ|ÀaJi%®É;�¹k‘õ>Ù'ÛRÛ•¸4ƒÊÕ{H×xËŸ³ ½¡Ðê(¼¸æ¡„8‡ÞDèL–;àÝ„P—…QŸECÐÅS²ÏÈx²ŽÂsuÂà$>Ÿ¾ÏÒ±ÏC8¬äŸQ5o¥U|1´¼•Ú0ãËh3_›¼ß/P^\IÛy;’öUt3_�²oÝÃ×Ñn¾žö }˜oDH¾	áõF„Ó›éM¬{›o�5ÜF^?EødùG]V·±B^ï—tÓÝÅ%òŽEMÐÉHK=É¨H¦í¢Q�Ôbˆ{·ë¸.ú5üTÞµÆøÉq�9.KŽ/1Ç³“ã½æx~rü¼9.OŽ/5ÇÓ“ãŽÿ�jÈ•V
+9jJ÷Hõ½�^¡× B¢wð×j©ît¸#Ñj|k ˜Iþ‰c²ëd×±äÇÃûT¼1èhjD¦`½N-ÔD›�yÏGo²ï6
+![·"S‡‘kCÈªmt?­§§(Š=×a×8rm‚ÞBÿÚHïbõ{¨$¯ÙQ—ÊY.2~×øéÿPKJ™öw»+PKÓ¥Í((edu/ucsb/nceas/metacat/MetaCatUtil.class�“[OAÇÿÓ»­-”
 DªZ(K�¾b­<ŒÁË£™n‡²Ív¦îÎ‚~+M$>øüPÆ3
 iô�¸sæÜ~çìÉ™_¿üDUÔllÛØ±±gá‘…'6-lY([¨¤a!—Bói$‘OÃÆ]£.˜c1ƒU2(b-ƒÇXÊ „åv�ê`�!¾U~ÏPÚjõøw|.»Î©<ÙÝ/O™>Ã}†ãÄÝÆrÍ
 ?ùNCI)\í)I¼�ÿÉ»}ûÀõ=éé3×—DCuCúÕgWL\È0×ò¤8‰úm¼åmŸÜù¿‹0äŽ…æ
@@ -225,7 +224,7 @@
 j+§B6§{·ÔÞ¥
 :4ì(4Åæ¿Ð”ªƒËjW‰°z.�
 ÚO ·Í.ÒÍ6‹9’Å‘4ž{(€á>iÏHš/—�
-1—�1›gCÜùF6†‡tæ‰ŠOb	i,cäY�4Œdå;Ò“´™‘q)zi+ˆ�B÷¨xÒ«\!óa{§z…l=±’ø:Îš¥`“¢*Èb›à†#Šám�ÃúPKÎRîÚ ÂPK&�Ì(*edu/ucsb/nceas/metacat/ReaderElement.class½WëwTÕÿ�0“;�›B’:€2 �ÉÌÀ¨¨I&aÐÄd€d <Êãfæ&™tæN˜{ÇÅG«E[ÄÖúhAE5­­U¬Lš²ê²Ï~ª«ÏÕÚÚçZþýÐÕÒß¹“„!¾ôÃÝgï}öÙgŸ³ûÌžþóƒ÷°kpÖ…	îsá°¸ð ¹ð°Ÿwáˆ�¹ð%O*øŠ‚¯*xAÁ‹
+1—�1›gCÜùF6†‡tæ‰ŠOb	i,cäY�4Œdå;Ò“´™‘q)zi+ˆ�B÷¨xÒ«\!óa{§z…l=±’ø:Îš¥`“¢*Èb›à†#Šám�ÃúPKÎRîÚ ÂPKÓ¥Í(*edu/ucsb/nceas/metacat/ReaderElement.class½WëwTÕÿ�0“;�›B’:€2 �ÉÌÀ¨¨I&aÐÄd€d <Êãfæ&™tæN˜{ÇÅG«E[ÄÖúhAE5­­U¬Lš²ê²Ï~ª«ÏÕÚÚçZþýÐÕÒß¹“„!¾ôÃÝgï}öÙgŸ³ûÌžþóƒ÷°kpÖ…	îsá°¸ð ¹ð°Ÿwáˆ�¹ð%O*øŠ‚¯*xAÁ‹
 N*xIÁ)/+xEÁi¯*xMÁë¨¸Óƒ…EÒîA:$éô Z›äDT’Í’ÜåÅõ¸ÛM“.jÐíE=î‘v=’ôzÑ€˜‹°EŠ[¥ñ6©ë“b¿>Ä¥¸]r;Ü¨Å€uØéÁuØ%MvËÍ÷Hî³’Û+Ýï“â~IH¢É}e,ƒ*aXS’¼$ã*¾CÅQ¤$ÉJrPÅÒîUñÆT|
 #*žFRÅ3Rñ,FU<'Å¯Kò
 è*Žãs*NHñyi<)É7‘Pñ-<¢â
@@ -241,7 +240,7 @@
 ;Ð�èócðLá_8'8%Ü8ÉÓüPTã= Âûb
 ~$îÂODGy²ŸŠ~üLdðÏôÖ,ÅyÞˆÄáMepè¹zÖ«ÇñÔ5#q{¯„�ÿ"Š…\¦$ê‚ËíšwÚ5ïbÍKðtÂâAðð/Æs<LÒY	ü˜Ï|LÀ”Wà‚§‡àé%xb´ÚÆ¯ŸàÙIðô<}Ï‚g/=íã·ŸžðÓžAî–à—¤;0Ä™aŒ>õãHñ¹%Œ$Ã?:!r€ÑŒ	“1mcTþÈõŸ´þ7îqX4à±ŠèbÄü73óèý™;%ìåeMaIO°€poØ¾›ãXªi-`ù@ˆÚ/Ðf´Ù|M›œ1êšš“¨ó·
 ¼5ZSÀŠ©¸YàÄùOf=.ÕŠYG‘/LÏÆ·çžÕnÞðÞâ‡ü¹ø%ŸÔ_áü«Y·â·¸�glaQ´óœ›ð'laql'¿å]ý
-YüøÂ'ôø8}±¨ÿPKPµ%ö‚PK&�Ì((edu/ucsb/nceas/metacat/XMLValidate.class}S]SÓP=—ÒÆP |	òµ
+YüøÂ'ôø8}±¨ÿPKPµ%ö‚PKÓ¥Í((edu/ucsb/nceas/metacat/XMLValidate.class}S]SÓP=—ÒÆP |	òµ
 H ¢-(" X�±Â>¥íµ¦M˜$íàOñÁñÑgi™áø£÷¶Edópvs÷ìî¹›ÍÏ_?Î á>6‚˜	â¡Œ9ó2’2d,Êx*cIAn*
  O¡„þy·ÈŠ×!Í 	Êˆ‚F…w[DÇTêrW@T€®bÓ*¸§â¦T,#®â¹ˆ®XÅkWñ1ëxÌÐ�¥Í²iL;o¤}×²ó	)ÛeD×…éŽþK¹öü€¡7šrÜ¼q\,žyll›®ÇÝD½à�0=Ñ·WWlIZ¶å/qÙÉq†¶”eó­R1ÃÝ7f¦@'ÝõDË1¶)Ë§\nIpäª[h¤ÃÌxMÊQM†QŽé¥½†&%í”Ü,_µDñèŽgæù¼&Ji{›©]³`åLŸkI*ðŽ(šãj;¯S$°�Âšåiå%W?:Ï˜%MCÊ9Y†Ï•ŒRÖËv–›žQä¾™5}c�ÛÜµ²¥2Œ^Ã½D
 ðcËgè¼b$åb¯2‡<ë_:J¿÷|N¬@Ñ´l†¡ÿé:©9'HN‰:Hch>Bäš-P}Õå~ÉµW\×q=†�û�kXŽ½YûÎÁòŸ{)
@@ -248,12 +247,12 @@
 —¾ FhÉ[ÚwˆÕ†xh§	™Ø^²MäÑúNÒÛGb
 î¾^…¢K'èÕÇOÖOÜ¯âÆ	:þv¿¡#PA÷)¤}áWÑº9AN¸‚žE{¤©‚ÎÏh%w¢‚®
 "_j­
-Â8TÂØOÿä ÂFbƒŽ	bÌbŠ¤Nã%Ù-Ì`�¸!<¡X]êIo";¤Ÿ>¡MtcÔMúŽ6]Š§N¯B½è×_D‚0I½¡Z=ô—bŽj£xôPK+v¨{PK&�Ì()edu/ucsb/nceas/metacat/metacat.properties}PÁNÃ0½ç+,mÒ.[ÓÆ!R%Ä†ˆ	Äà¶KÚxm¦´‰wëþžtŽ\,ù=¿g?OØÞ½uèIc€ƒ6
+Â8TÂØOÿä ÂFbƒŽ	bÌbŠ¤Nã%Ù-Ì`�¸!<¡X]êIo";¤Ÿ>¡MtcÔMúŽ6]Š§N¯B½è×_D‚0I½¡Z=ô—bŽj£xôPK+v¨{PKÓ¥Í()edu/ucsb/nceas/metacat/metacat.properties}PÁNÃ0½ç+,mÒ.[ÓÆ!R%Ä†ˆ	Äà¶KÚxm¦´‰wëþžtŽ\,ù=¿g?OØÞ½uèIc€ƒ6
 ºÕmÖ‘¶mD­ª¶Hr-i‡þd�’£<Icm¶’^l‹aÙÂ“®*Ý†ÈÌ¦ÏJ@Õ¥¤Äý­›Ÿ Kî`™¦)OïxšÁòF¤+q»‚ãà�½ƒéŒMX×äWŒ9ÂÙz•_lçî¼¨,†E�Y<\v†6ùQ¥°^–Õº÷Æ–ÒÔ6�ÈVËLbªØx}ŠÎãd2¨u…’·+4òÌcˆ¾;ºüúxÍ‡/	Îymä5‘S±6†÷�!«
-ntÁGIˆoêƒa‘‰Ñ¥±Õ ÍÿUþ&ÔÓo"!'©Î×bÿ‰�Û3ì±ìbˆÒkGù�&)$±oPK��´Û:ÏPK&�Ì(%edu/ucsb/nceas/metacat/TextNode.class�RÛJÃ@=i›^ãÝ¶Ö[kÔ£5à›(>¨)‚Åß¶q)‘ºÑf+úW
+ntÁGIˆoêƒa‘‰Ñ¥±Õ ÍÿUþ&ÔÓo"!'©Î×bÿ‰�Û3ì±ìbˆÒkGù�&)$±oPK��´Û:ÏPKÓ¥Í(%edu/ucsb/nceas/metacat/TextNode.class�RÛJÃ@=i›^ãÝ¶Ö[kÔ£5à›(>¨)‚Åß¶q)‘ºÑf+úW
 ZÁ?À�gc½€|93sæìÌ$3¯oÏ/ˆ¢‚¥f(¦¡!�BFš`@qƒ
 †ÈaÔÀ&
-Ì¡`ÀÄ¸�yŒXPÞ"Æ4Œ[Ë‡çìš9-&šÎ±l{¢¹©!j-ŸhˆYUe²Öo‰â·{|pÕrv}!¸+=_lV«¿åýÄ·<áÉmj´ëŸqšûÐ¼Ö¹hðv�5ZÄŒö.Û·-ý�c¿Óvù¾§^Ôù�¬QÙ5%¦.I5”øYÇé¸AÃ.g�sÁ%s™tvXà¹µpŠâ’Ï‚2Mz{LRå¤ør3ÁÏDªì}gê·—ü#:bm.¤Ê%¥ÿñm´¦m„µ·Ð£Õ‘�ŸC–0OÑ)�B’lÙ~BÔÖ¡Û+�ˆÙ¥.v.ÖEÊ.Ä»ˆÛ…DÉ{Rj˜ 4ÃW&UË#EW0¨Žeê°„",ŠLR–0Òë3CVÍ£ÛÐï¾ÊÄCr��Nª'5Ã¡)§&Ñ¿[¦C¶«Ä”ÿWzƒp*üúéwPK�F¶ «ùPK&�Ì(&edu/ucsb/nceas/metacat/BasicNode.class�VësUÿmš´](RZI´%¥�/)i)¶¥-H+µ¨À&YÚ”dS³¤øDð�Š|G|Œ3ÈøuhddœqFG¿øÅÿFý�ÍvÛ,;#ò»çžû;çž{Î¹{óû??ÞB)Úq1„ÇBØÂþFƒH1Ä‰ ^âÅ ^
+Ì¡`ÀÄ¸�yŒXPÞ"Æ4Œ[Ë‡çìš9-&šÎ±l{¢¹©!j-ŸhˆYUe²Öo‰â·{|pÕrv}!¸+=_lV«¿åýÄ·<áÉmj´ëŸqšûÐ¼Ö¹hðv�5ZÄŒö.Û·-ý�c¿Óvù¾§^Ôù�¬QÙ5%¦.I5”øYÇé¸AÃ.g�sÁ%s™tvXà¹µpŠâ’Ï‚2Mz{LRå¤ør3ÁÏDªì}gê·—ü#:bm.¤Ê%¥ÿñm´¦m„µ·Ð£Õ‘�ŸC–0OÑ)�B’lÙ~BÔÖ¡Û+�ˆÙ¥.v.ÖEÊ.Ä»ˆÛ…DÉ{Rj˜ 4ÃW&UË#EW0¨Žeê°„",ŠLR–0Òë3CVÍ£ÛÐï¾ÊÄCr��Nª'5Ã¡)§&Ñ¿[¦C¶«Ä”ÿWzƒp*üúéwPK�F¶ «ùPKÓ¥Í(&edu/ucsb/nceas/metacat/BasicNode.class�VësUÿmš´](RZI´%¥�/)i)¶¥-H+µ¨À&YÚ”dS³¤øDð�Š|G|Œ3ÈøuhddœqFG¿øÅÿFý�ÍvÛ,;#ò»çžû;çž{Î¹{óû??ÞB)Úq1„ÇBØÂþFƒH1Ä‰ ^âÅ ^
 âå ^	âÕ
 ,Âú
 ÊT�Å‹©M6”sÚ.Ð!¸OVï/G³+Q‰‡DÚ(ÒÃByD`“À£›+P†N¡l‘éV�mâ~»Š'ñ¸À°Š8†T$ñ„
@@ -266,7 +265,7 @@
 §CmÕÊ,Âœ…«K	£mí"–ˆ(k\ú÷6#h�ß¾ƒÿ2dÃ.ññ_ÅÇã2›á–ðSì3¦ásVä2Fð­²Øå„á(Á‡$³Xå=Ô_Ä)t;ì5<”h‘]÷�‡z’øœ/µÁK=HÌ¡Ë¥*.5òµ‡zƒhºY]H­÷ÆúÑò
  ÑÀ$1ïKmöR��ùÐâ
 à<ñ¸{¬&çö©Ñ±kX8|€7Í{º¿‰o²(‹.ZÈXÕö+–Ú�Æ>X7z•?`uu`MÞN¿ÊNÿŠ]~Ëð-êð%Wßb¡þerAë¼]~–ÎPó¶?¿ÁËO’§æô¹üÂ­(‹®.º…þ-ò¢æ¼{ùçù¼Àõ^þoäß¦æ]ÿx½ü)ò
-jÞóç7{ù/’‚š÷ýãiñò/’�Íþ¾>õPKêæoO–RPK&�Ì((edu/ucsb/nceas/metacat/ElementNode.classµWkpSÇþÖØ¾WÒµ1»´ h‚…dP^†Fv¶‰[[à@(äZº¶åÈ’‘®À¤4!)!}äÙZhÓ&Mçá)Ç!MÛdši“–iÿtú M;}N3ÍL¦:ÓôÛ+ÉFPøÑÑìÙ³çœýöìž³{�ÞùÏko`–ã-÷©øŒŠTìWñYŸSñy_Pñ�Š‡U<®â‹*žPñ¤‚Ã
+jÞóç7{ù/’‚š÷ýãiñò/’�Íþ¾>õPKêæoO–RPKÓ¥Í((edu/ucsb/nceas/metacat/ElementNode.classµWkpSÇþÖØ¾WÒµ1»´ h‚…dP^†Fv¶‰[[à@(äZº¶åÈ’‘®À¤4!)!}äÙZhÓ&Mçá)Ç!MÛdši“–iÿtú M;}N3ÍL¦:ÓôÛ+ÉFPøÑÑìÙ³çœýöìž³{�ÞùÏko`–ã-÷©øŒŠTìWñYŸSñy_Pñ�Š‡U<®â‹*žPñ¤‚Ã
 ¾¢à«
 ^Pð¢‚—¼¬àˆ‚£
 ^QpLÁq'œTpÊŽÙXgGM–ÜbGn•¤ÝŽ9’ÌF‡TÜ&I§$]’ø(ºm´[oÇ<l°¡=8Ñ+g„$ÙèÀ|l²ã#è“ÃÛåŒÍR¶EïpàcØ*‡Ÿ”Ü6	°Ý�«p§ÕÐ¥I¿t#,ID"R6 É $C’DåâÃÒ¡a
@@ -285,7 +284,7 @@
 éƒA„Ù;¤§ºI#ç:›[$yN_è`:[Ÿ ÎHÆÂÆ¨ÌbÞÒ™7ž‰â¯Þù¶»S|Øò«Z¢ÐoYö&Í-raæ_üyäÓpág‰7oJØ»¡³Àéiã„š¢ß/æ‡|'xÎ²ËC—H“V�f)@QFåñÅ8OKD“¶©é`ÊxñÈ+)Ê!¶ÇœœÊ‡Ø–ÊFµ}-WNFXŽÖ[×Mêì©‚ ªf"{àXÌÂe6¾½²Ð WNž¥	é>Ž<”—°·{&°Ðã=
 ÏqËúÒJ–|€¥D±±—óîÍÍ»‘ºRöUï{\h–äæéÙÕ–Þ‹2¬€×Ñ�…°7‡ÐC•ý’Bk<µ¥´zœå´yœJ-30B!m&æjb®áÞZX±µ²¦[G›¸V;Yü’»és%'Æm­¶UeÂ¯¿*ü6Ï)xªµIøKà·;í¥‹&±ºNû$–ôÉþ¿Ãé˜Ä*�•Ú8Þv:J'qm	Z�Ž2‹YUæt”OâFB(N‡’åT§CÍr6§RÍ�x£‚Ü,r‡à:ƒªÍríÅµeNÕ©L`‰¿Âã¬ÈàêqÜA³Ë¬ÒC¥-ƒ¦q¬£°Ò6�Áœ©¹69÷ãÓsù+Nà¦3¨Ù\]>—”^—�;ƒ@�S»¨ÑØ8Žf¿–7V¥±Vh,±yµ"ÕŽó°x4ËÎ³*»Àê8£Þ‚sxÐ lBc_/¼ÂË¾RÅöÙXþ+IfÌa<e.<gÌ°dþ<Å²ú kî'9ç\Í*¸žEp=kà–À
 t¥™p^`{x	!¼Œm8‚!EÇ°Ç±'¹Â)¢œÄaÖÊOSþ,Ëå#¬–O³•¿7Y/¿Ãrù§ìÆ:GÌ÷X*ÿŽ•ò¿ñ–(ÅóÂ†ç¸›ï‹J¼-Üä½ø�XŽŠ[ð®âwö#Ñ‹‹<Ä=½>•‡÷ðDdî,’‡—Ÿ‡5Ú!lºâLÇÎKåÇ8úN ÞRÚ©\”ÁÒ¼âÿŸ*Ù^ä®=‹­Ç ÌzT>ãðK¤¬§6‰Ä©îóáòjÕ‹§6rœ¹Õ»d>2;^‘ùˆ³ü1ñ>>ÀQ+E3ææòò,n ½�1ìäÜ.æe�yÙMë¶ór3ó2$ÿec+ór·³ÝÉt¶~æe˜«FØ¢`©Â0¢ô%Bo†±wá	ò§_:=e¶îÀ»äÏ"…ŸÐò¯Ì¢÷¹îœñ/Œ‰*ìµ¸‡í^áÁ^áÃ}¢÷‹FÊš±O¬Á¢ûÅVöÛñ HóVù÷.÷æþ–»*c¿OžÔuz2¸¾«ÞŠÀ!,õV5epMŸ—Òž«Å¬È`­ÅW5K�Ræó—Žcž“¹ø	Á¿‘³ƒÞåÔõIÁJ�Ãþ%�8ß[-ò@
-(^çØÔ«ÞÁ3~Î“þ*ð+¾èçøgü×XŠßàzÞÃ›ð{4â¼åÄZü‰±ø36’ßÎóÂß�Àß1†ðÛôO" V	ü/PKqô˜³PK&�Ì(&edu/ucsb/nceas/metacat/DBSAXNode.class¥WûsWþÖ–,Ù^§®â¤¸´õæÑD–¥(¸IšØMlÙVZ¹¶ìX²�W	ki­¨È+ew•8}ÐRh“6¼úàQÞ4$¦”
+(^çØÔ«ÞÁ3~Î“þ*ð+¾èçøgü×XŠßàzÞÃ›ð{4â¼åÄZü‰±ø36’ßÎóÂß�Àß1†ðÛôO" V	ü/PKqô˜³PKÓ¥Í(&edu/ucsb/nceas/metacat/DBSAXNode.class¥WûsWþÖ–,Ù^§®â¤¸´õæÑD–¥(¸IšØMlÙVZ¹¶ìX²�W	ki­¨È+ew•8}ÐRh“6¼úàQÞ4$¦”
 ­‚›RÞÌ”�ÂÃ_À¯üÌ0ÃðÝ]IVcyÆ…éì¹÷žsîw¿sîÝ½üÏÛï¢!¼ãÅ9/½xÄ‹G½ø”Oxñ¤Ÿöâ)/>ãÅ/žõâ9/.yñ9ž÷à^ôà{¼âÁe¾ïÁ®z°äÁ<xµílA‡#"­ø(†šáÃp+nÃH36!ÚŠ�à°¸¿…�XnE¬�mÁf<(úÆ„".Œ'„6)Ä!¦„qBÄKŠÈÓ-Øˆ10+ÄQ1Ç1!Ž‹æ	!N
 ñ�§¾OªŒó8#ãóÈËø22¾ˆgd|	ó2^ÂÓ2¾ŒÓB2¾‚”Œ¯
 ñ5de¼Œ´Œ¯‹æ70'ã›Bû4ßÚwÄèwÅÀE€×D¨¡ ãu1Û�aÊø	t?Å'e¼�œŒk¢ù3<,ãM¡½%D	2®‹P?‡%¡Ñß³å¨„÷ØÃêY5œSõL8aY=Ó/as¥Û<“Oif1g%4ëæ�„¥ZÚ‚¦‹†›±åq	.LÄö¹ý±ÊsT<7ûc«§.¿=ô×^Õ5TœŸ×N¼{ms�qÒÐ
@@ -300,7 +299,7 @@
 ÁŠŠTM�Ë9$�i{ª&ï9V2˜ BJ‡Hæ8Ä›D„w?íFqŸÛ¸}‚˜d
 A?¦8šÀ8’Lä44Ì �Y>…'Øs	ÇyA8�Ë8Éïü‡ð6Tüsœw€3§˜ª4þA¯bÿ¢þod¤&–†Ä"ÒËñ&ÎÅgÆN‘l§(ruÙL…ÜU2C9NíÚ¶më³]Â†8Ë<TKÌQ‚®'à�¼Í¸x™iâSÆ+¼0]æ6¼ÂÊ¾JB^ÅnÞlzùÜÏ¥²¢ä]fŠW™£ô=ÁÛÌI^fæyA’HÃ™òâ.”«½ß¼Á<,W_ppÐ¬'à`-à ÷p/áþ
 †7	Ø`Ï9^$àGøQÚèñA?Îí˜§ç�*ãÊŒ; nùßY\
-JœÅüY‚ºqËìà%³‹×ËxžöÏÐã‚z‘ ž¦çEÚ7àñÿPK0o=GÒ£PK&�Ì(%edu/ucsb/nceas/metacat/DBWriter.class�Wû_Sçÿ	œ�ˆTTZ/Á®6†@
+JœÅüY‚ºqËìà%³‹×ËxžöÏÐã‚z‘ ž¦çEÚ7àñÿPK0o=GÒ£PKÓ¥Í(%edu/ucsb/nceas/metacat/DBWriter.class�Wû_Sçÿ	œ�ˆTTZ/Á®6†@
 ^ª�b� b“€\Dêœ;$'LÎIÏ9Q´·ÍÙÝ×­í¶nÝ¦®®uÝMÅ´Ùì®Ýå§ýEýìûžúégðÉó¾ïó~ßçþ¼yóŸO?z€*´âßn¼æÆ×Ýøž¯»ñŽ?sãnÌ¹‘wãŸ2~(ãG2~,ãm?‘ñ®Œë2~%ã=ïË¸!ã×2>�ñ¿•ñ;¿—ñ7eÜ’q[Æ¼Œ{2îËøHFÁƒÍˆxàd§ õˆz°A�FAšÙ†˜uô`-†<PY'HŽ{°Ãk±#µ„Œ
 2V‹GqBˆ÷à1œôàqAÅ„�ò¼8qÊƒõø¢À�ö _¸3<‚/‹]UÈ›VÅI¢	’B§„Þ)qbJ€§\ÂYAr‚œdV�‹
 ¾[Á +xC@ÞÄw¼…o+ø)¾¥à
@@ -316,7 +315,7 @@
 û&µ½ÅH¾Í|¼ÃÊ¼Â|\e>®¡‡ñ<BÜ1¼‡çð>�ÿ€Ñþ�rŒ—\Ìj
 ¥]ö?¨y©·�öôˆ±J‡¿ª#âwuDýÕ1)ä"ê:ÖÎa_ÈunMGÈÕPÛä
 ´ÞÃ3ÂÃº–¦êy´Î¡Û©6i)
-N!z#Bðš¢nà¬…Ó<ž½�ªÛ´i3âìµO“üÉì¡…ûXuûÉ?@DˆŸ.öã3ôXôð!öd¬½vŽ{ÆAvb'}>Ä¤…Ù‘QþÇy.‰AVàkí8Ó7Ì(„…vjû®s‹]þPKã²Ÿ*ŽPK&�Ì(,edu/ucsb/nceas/metacat/AccessionNumber.class¥WWÇþ+Äº‰ñ£ÅØñbc#„âæ!;ŠAØCý
+N!z#Bðš¢nà¬…Ó<ž½�ªÛ´i3âìµO“üÉì¡…ûXuûÉ?@DˆŸ.öã3ôXôð!öd¬½vŽ{ÆAvb'}>Ä¤…Ù‘QþÇy.‰AVàkí8Ó7Ì(„…vjû®s‹]þPKã²Ÿ*ŽPKÓ¥Í(,edu/ucsb/nceas/metacat/AccessionNumber.class¥WWÇþ+Äº‰ñ£ÅØñbc#„âæ!;ŠAØCý
 ^¤DÄJÞ]Ù$i“¦uÚ$M�¦nÚ&é#uš’&nk\# Nóú£zúÍ®2=é©ÎÙ;;wî½óÝ;ßŒfÿõï/¿F9ZðO/^ñâû^üÀ‹×½ø¡7½xË‹·½xÇ‹Ÿyñw/È¸-ã2>–ñGwd|"ãO2>•ñg‹2>“ñŸËøBÆ]•ñ7jÐïÃvø°ƒ>lC¸Šâ”èžâ9¡‹Tcžgª°CÕØƒaž@TŒŽøP‹³âí\5ê0*Þb>|cÂí¼p÷a&ÄÛw…Éåb5¾ƒK>|—…¸"Ü^bR„¿*<4!¦¾¸ÀÝ„‚ïaFˆ”Y!^Rp?Qð.^ÂRðsÜPðž°ûÞTðKüXÁû˜Uð+\Sðkdü
 >€©àC$|$Þ~]Áï0­à÷"Þ=a·$Þþ!|—E”l+bò1ùªðXÅuk0|‰9!æ<_!-a§¿ihN»®µ¥4c¦-f›Ic¦KÂîuµu-Õ6ª[Ù”Óm”û›ÆyQ‚ÇiŠHØÅ¦TŒºRúþìô´nv¹Îãb¢Hio<®‡ýEú‘©9=nw•Œ°Ë_"ñ*¥/R
 ¤4ËêÚ4Q	»ÂDÁodXÈüÈÖæ¢ÚgM=£™z"fk¶>¯öV©°�%ôÿ—%WuøYþ×Ò†ÁeI¦
@@ -327,7 +326,7 @@
 ,â
 >cìÛŒþ9^ÁŒ›»ìMÎÄ¯ƒ<‹¾"‡D=oH£v>Çr8ô!Z
 Ýt‰lDw}LI”½Á5iÝs,shîfÞu9¯+û^O÷"*oJ’3øÛ/Ô­`½¥£Ñí UXÆÃÎ2]æ¾¸Bv½À� ¡Ÿµ‰ N>%È'IL9?qò™¼ÎÅ'LŸ³*�ýmÉï‡–üVnq÷Y]_¦
-¢h)fý’Ã¡ƒ±÷8)>IŸ!é¯qÌ¤MŠc6#ËÂÏÑú§´)Ã«ÿPKßÂIâÖ!PK&�Ì(.ReaderElement.java.swpí›mlGÇ'ÎKóÒ´Q		
+¢h)fý’Ã¡ƒ±÷8)>IŸ!é¯qÌ¤MŠc6#ËÂÏÑú§´)Ã«ÿPKßÂIâÖ!PKÓ¥Í(.ReaderElement.java.swpí›mlGÇ'ÎKóÒ´Q		
 ÓkÁkçtg'M;nk;Wjd'éù’&"¨ÝÛßm²·{Ù™õKš©B¥ðR¾PH¼TQ!¡‚BT5ˆ•�RR(íšôC)¢ˆ Q(ÿÙÝÛÛ½=Ûç%
 ÝGú)¾›gž™yæ™¹Ý™'å¾}ct[îNÙ@ˆõÔÐÇ&%äÀ{	9d[Œ“Å¥Ê˜Õ�9áÌ×ûÓþ(y�M3Ó®×˜%ò³5SØz9Ï-Ït7ïj¼œ·4¦ò|�	USE¾ÈT�9“É
 ¹Cê´ÚIÃ©¤’Š'[·ô÷Ýž¹�¾ë–½×º+©¤’J*©¤’J*©¤’ÊUQ_NÞÆ¿]@¾ë/XY|^n¯ŸSI%•TRI%•TRI%•TRI%•ëGT���ø÷ïò¥~ƒðÖÍ„œŸ{À:ð^þŸßû@ÜúA¸,×ò<ø%xœû@PðAÐ–�Þ]ð,x`Èƒø¸´Ž�¿‚ï�:¨‚x?xøÏZB^çÀ·À§ÁIp¸àãàðöB~A	¬¿ZMÈ�Àp<FÁX^¿��àUpX`/]²l!gÁ�Á“à·�7Vòx
@@ -351,7 +350,7 @@
 ¬”eëùx||Ì‚C`lÿ^KÈyp<Ìà®#¸¸cß'A(àÅÕ°	æÀ½`8!§A”À$è/­"äðð88>>
 þ¶’�WÁ³àpÀ'Á¸´‚�7À_ÀEp¼N;‚ûýµÁýþËà‡àK€ƒ»A¼l¯aŽÎvùsuäÀ*ðûe„ü.zÏÆJä�ÊßJóˆ=zé9²DýŽíFOFµ¥6•Ëj0X(Ñë:ïvk�ckŒs_°kh®Ã�ifÎÑ*sXd]6×Ñ·‹áð.Bé‰ìDÿëÓ½£ûòv˜–+/ß‡á�]Ä¦¯8âNM1Ço[ú�ÍÄ
 Â-58¬7ÆI•6'ü¡»åµ¥“œbr·,Æzš�‘ð¸ÓŸwyŠ«¼nªshÖ;åT‰Î�Î¸æÉ‹ªc»•ªg/zq²¹ÛÎŸÚïÙ	C_0³£ƒŒŽ4Í&Ù0í(“Ã›¾<Ö§å�M#}BêÉ%k;:5üË"¶CZª^£LžD«±M¤!ª®{;˜\‚m~åÛKó’0™0á¥o$nÞ£R‚ãdsÍ�«ºñ¥wÅ™mÓwfrÖ~£)ö»L²-ÙÃ;ÿ°Ÿmº·PCÃ¥Rqldo©0_kWÜ™~šÀ‚ÞŒ_F]+™Ç¯�öC�$°s÷èÞ`OOT‘[øWàØ±dL¾³ÒË‚gàwX†YÂ…^•ÝÅ�…"9àÛ³t6ÛN±}:ZËŒµKJ£ä¥ÑRÓèbÙi‹Ô¹¼âæÚ¿b9l1KÿoÉkñ„�EÒ×˜ŠÌfòN,IM^`{wåþƒ¡!ikÍ_ó…²É:È'kÉ(k2ÔXø±û)]`‡¦‘g€“â°‹þSŒí:A²Ê¯îCêPKà_ö´W
-PPK&�Ì(.BasicElement.java.swpíš[lWÇ‡¤4ÙÚRÄH'›¯�ÍÎ:M(Ø¸Â1nã*n´EéÙ™ãÝqfg†™³Ž·V*  !´RÚ
+PPKÓ¥Í(.BasicElement.java.swpíš[lWÇ‡¤4ÙÚRÄH'›¯�ÍÎ:M(Ø¸Â1nã*n´EéÙ™ãÝqfg†™³Ž·V*  !´RÚ
 ¡
 ‚„�¸$hÕrBíS�
 Bô‰Â7ÁÿÜfgvgm·HEˆù”_¼;ç;ç»œËÌ9³­æêÒ29Ñ8nA®·¬ß|qîí+XÖOß`YëaÀkgé0ìBÍº_6hGq¸ÎŽ-ÏvÙóÃ¨Ënov}º-;‰›¹=»ç$-;pMì.ãÔ¡Ü>IÏYô™Ðo¬Ó
@@ -369,7 +368,7 @@
 |l�ûÀíà6p5¸‚=þsàçàsàQÐsàfpûÀï°×ÿx||\8
 n‹àFðÇ–õcðx<ú€‚»Á]à¨€*h<¾>: (¨‚¿!/WÀsàYp	¬ƒSà0·_åN|.¥”RJ)¥”ÿ¹¨7!â?½WÐg6GŽäv$³©†~ŠõäÖ-Ýîåv
 ¸Ž-bÂû¹¡m¦xËž˜¶�ãŽ«Ì^Â�$éæGû“=:n3¾ õ…_£Wxîb}ýX—n¢Ì¡–ÜWÓ¤îP×­É/ù]”<»C™Jš©åž÷U�¬gó.ôuv¤Yì€wðÁlžÄA‚ØCžÑJéÙ>ç§'Æ¢¥m×=‘îÙÆœ§3¿³™mÎYÆF(‹kÃÇ£AJƒžlw7¡æ]Éu°°ÕÎ~0ˆ@�.i¨ð˜tÔ¦ÞäŽL“½ ¥õÌ©¤É¶Ùõç�(„õ!ã9«úäTÌ×s¦…¢á-ÕŒÚ§L�!Ÿæ¥º×ÿ©gN«·V'	§1¯3vG÷œ�ïþ€®(:OWÑÀËôµ¨wõmü+¥Zþ­Õð°¢Áà@HŸc·úêjØó—`w›pÖm°8nDhœûA­šT•»½DŒYNZL¾&;XM�."b¬åð#m0[ÔKc«§/â2ÇÐ¶�¥Yl¿soÆÄñœ¸Ð¡I‡Èó]Á[#¦9rP½±:ª6ó~\ÆêÃo³)TË¬¸
-\1+­î×:ÁÍ	íË�¸Êð˜žÆXÊÎPU6’|¡¥Çmê‘¹P½§Z5	)ªR%ÕÉLu9$Ò²9YÝú7PKÿëüõç@PK&�Ì(.TextNode.java.swpíš¿oEÇ'HD1„$	AÅ‘lŸÌí%„Ÿ"a.aqvh¢¹Ýç»1»3›�ÙÃ")"Ú€	
+\1+­î×:ÁÍ	íË�¸Êð˜žÆXÊÎPU6’|¡¥Çmê‘¹P½§Z5	)ªR%ÕÉLu9$Ò²9YÝú7PKÿëüõç@PKÓ¥Í(.TextNode.java.swpíš¿oEÇ'HD1„$	AÅ‘lŸÌí%„Ÿ"a.aqvh¢¹Ýç»1»3›�ÙÃ")"Ú€	
 j¢�ÿ�Ž	ÑPPðÐ"Áwf÷|?â+‘¢ùJïÞ¾7ï½™y·Åyz­Ëëü•æ9�bìê·ç_Mo2vìÆvµ"Ãî­‘:„»îFy¡w)¶¸éÉ(¡!¥:ÏHÙh/K­Nz‘)âˆ’2*cÓ‹TLÂDYmÑžÝÔ	5wÅP&gPPÐD/Ÿ=Ózñ…çùSOn?èR‚‚‚‚‚‚‚‚‚‚‚þgÙüû×G@©	
 
 
@@ -398,7 +397,7 @@
 ÷Kî<]‘=aÈ?©	KãÇK%­©üˆx`kŠN*c‹þVôádµ%žÏ»òBQÇxÏ¼¦»¾LÓöŒãdÓªÆ`õ¾Æ©0f’WR‰á¯#ãºÏ\#¸íkp¡Å{¥L.­¡t‡ï:CÙLÝ
 YãŸÁ„�¼Cð=VüÊÆÛãÕö‘Ï
 ¶Î¾Â0YÆd–ëÂrwP»i®¥Í†+\Äˆ>JMÊ¦;ÝÝô§»›õén8ÔÅ:]¦Â �U¾xz=9½ÈÜŠW–µÒtaVù†°–¿åO©×¦}múW�Hy%Qáûáb¬SÝ—1ž®Á42Òøâ»#…À§*JGç£Böv•ŸmµZü]êûi×�¸­ðö@iväžtÐˆ­¤ð¡àpG)÷±òN—Ê"×†Vïµ
-[ã·ø1)eSd5{|ÞmÓ¿PKÓíe‘ú0PK&�Ì(.ElementNode.java.swpíœ{lGÇ'ŽÓÔq^MyJ<&×´^;Ç�í< NœâÇU5øÛy4¤D{»ã»M÷v/ûð@
+[ã·ø1)eSd5{|ÞmÓ¿PKÓíe‘ú0PKÓ¥Í(.ElementNode.java.swpíœ{lGÇ'ŽÓÔq^MyJ<&×´^;Ç�í< NœâÇU5øÛy4¤D{»ã»M÷v/ûð@
 „„
 ü‘	$@Q	BJR”ˆ¡B”¶”–J�´P!RøÎîÞÞÞíù‘Hç'}”»›ß¼~ó›™��Ÿ“mÝÑ7@7¤ÖÈJB¦OmÝÔwˆ�Ó
 „ì3
@@ -427,7 +426,7 @@
 ã.`Z¤*ëuŠNŠÕZ±ˆ”DVUoùâS°ÆSJm)_Æƒ@¼�”X4ATÆ`¸Ê•³ºô£wu›¬Ñv¦Û¬öB3–Ù¬2ñºìÈ
 Æ1„í¬Ñ¼Ù*êéëÞ>–™©¶knL?ôaVkF/;£�ü>ƒM!µ»‰w¾w¨g{°žÇ²pkÍ¾8÷ÇWV¸\ðtñ
 ‹˜‹™ÐË24Ò›¡Ý÷øå*›ª¥X;¼®jÄjÙÑyÄÙÑy„ÚÑ¹¢íæÈsuÉåyÍbò*JºÑ‚ñ*ƒ�æÇc26Ër@REÐ¿£÷Âü‡BÍ‰…áEvÐ`g–UÞÂ½jƒ};l÷ì[@¸X­¥F1¶ÙóóÿRœ×w÷ÿüŸïáœÿ-ð0xLƒ) ƒ5 üŠ�‚ï€Oùß^V‚Ëý¿8>40ÚÀ«Á«ÀßpÆü
-Fpþo—pÎ<¦‚˜ÿ!0îõ`a£óÿ4ø8LÐÞ–‚gp®‡ÁnpX^ÄùÿIpl-àÏ8÷Ã üçýsà,8Æ‚÷= <‡3þãàë ö€Mà%œë/€óA<0 ‚wƒ{Á¨OFÎÿß;Á�+ÀuðYp|ìw‚×�— Oóú�J~!£â0*£â0*£qµJ‡Qq�Š8ŒŠÃ¨8ŒÆòˆÃh,í†9ŒÖ�ÙÏ•%­Z§Øè³NPˆ¿û‡õ»ü ,7lj<‚¿¼ÛÅÈSNùac¶¿&›Çß“UýEY�ÃõìOýXòé,›Hdëñ]�„•ÎürX:Fü.Óµ‚?ÿAú5}žþ7PKÑ=½Ug`PK&�Ì(.DBReader.java.swpí›{lÅÇ'ò€Di©
+Fpþo—pÎ<¦‚˜ÿ!0îõ`a£óÿ4ø8LÐÞ–‚gp®‡ÁnpX^ÄùÿIpl-àÏ8÷Ã üçýsà,8Æ‚÷= <‡3þãàë ö€Mà%œë/€óA<0 ‚wƒ{Á¨OFÎÿß;Á�+ÀuðYp|ìw‚×�— Oóú�J~!£â0*£â0*£qµJ‡Qq�Š8ŒŠÃ¨8ŒÆòˆÃh,í†9ŒÖ�ÙÏ•%­Z§Øè³NPˆ¿û‡õ»ü ,7lj<‚¿¼ÛÅÈSNùac¶¿&›Çß“UýEY�ÃõìOýXòé,›Hdëñ]�„•ÎürX:Fü.Óµ‚?ÿAú5}žþ7PKÑ=½Ug`PKÓ¥Í(.DBReader.java.swpí›{lÅÇ'ò€Di©
 erDáì¸{¶#Îv‚qêGbÇˆ£d};¶7ìí»s~R¤FMÿJA-¤BiA¢TÑR”Š¢"Q
 ´Bþ)ˆJA¢´¥P©Ð¤--ýÎÎ>ïa_JýcÊ'¾Ûýí<~ó›™�™ßM´\Û?H/W.#�5„¼÷Øæ+·"ä_+	Ùo™Ì!‹Ë4cfjäKn‚™¢mígyŽzFc3Ì°ŠfòÌ\Áà–6‘qì|†i¥L)ïLdÌ<S�L�q5¯òL_ÏS5f+ûÕµž<I$‘P.mkm¹8µž~fíØ§]”DI$‘DI$‘DIä^\J>Âß0ÎðXÖ�YïûR ƒ;½ïKˆ»]@þé}O$‘DI$‘DI$‘DI$‘DþEÕY…¿'Å"~�Üøp5!¯ƒûÀN°<{.!�Á^°Ü²àJp	Xþx!'ÀOÁà1plW|ü™þ<
 w�;ÀN0ÎÏ¬$äË ´€eà£„ü¼î�Ÿ+À‡Ë	y<	t‚Àùàƒ³	y	<îGÁ�`4�Î"äyð8¦Aô�
@@ -446,7 +445,7 @@
 à}äù¸|{•,Ch¿E™ÇÁ7óÖýïa]ÿø>ø.¸7ƒ=àz°Œ€óÀðk¬õ_÷�¯ìí‘ß¬g€g°Þ¿
 Œƒvp àm¬çŽ‚[À.oÍ¿	|œNb-ÿpÜì­ñÏÃzýÏàx|Ã[ã�‚­ 4‚àÙ¥„<
 ž÷ƒ›€FÀø"èW€vÐÞ]‚ò�çÁà0PÁ>°ä@øK!¿?w€¯�#à+`ì[@#¸¤’eQ²,J–EÉ²(Y%Ë¢dY”,‹Nû²¨žµ‹?æ†cï©¯ZZ³Ô³b9ë•S]­,°V)·Ýâë”�½J©ôùš+”:×'‘^T}¬|®ìƒe®ýá§L³§49Él‘²WÇèe™}ü¥µü7Xõ÷¦°gˆ—¨YFgU|�ÓÛ:›aZ¤?M«3"+Ïøb^’?†�w{Ý0îŠ_5Vt/ñCÛ}‘™Õù´{ËoÎ=/üÑhÇ'û®T}úºTíìÝš!GóÑ¨£ñÍŽEr“ê‚ÙÕ•aùOÖâßê©¶˜v)Ç"e)Ë2ö³aù"§y¤ø_PK‚�Bô¡
-`PK&�Ì(.DBSAXElement.java.swpíš{lGÇ‡&Mâ˜Ò¨B“«QÎæzg»y:2ÍÙ>ÔkýŠ_¤D%¬w'w›ìí^vgý¥ˆ§*P…
+`PKÓ¥Í(.DBSAXElement.java.swpíš{lGÇ‡&Mâ˜Ò¨B“«QÎæzg»y:2ÍÙ>ÔkýŠ_¤D%¬w'w›ìí^vgý¥ˆ§*P…
 $¡P¤VH¨•ø*@ªJ‹
 TŠ„U¢*E &å%$ú …ïÌîíãîl_BT«Òü”�³·;ó›ßüfæ73»³Ø¿Pž ûò{	ä&Bzù�C³Ÿ&äæ›	9åØÌ#K•1»ƒdä>©°Pw�SLç¸X4[b–S¯1›VjwŒÅ‚çêfø_÷¶Î4¯Pc\Ó5^™-+YL¤ÏŸÒ–´NÊU¢DI ·ôßšÙMßñöùÍ6E‰%J”(Q¢D‰%o°ðúrÿ_no	Ù
 Š þÞzDúð·%J”(Q¢D‰%J”(Q¢äÍ#šAÈë]„<¹“ÈïÿâÀo$ä%ð%0¶ƒ¿¿��¿€‡À9ðÀ�>
@@ -471,7 +470,7 @@
 úÂïüÂÞþið°Á½` Ü÷_þˆ=ýïÀ3à1ðeÀÁmÝÁ·þGÃoûÇ@dA¸¼ü¡‹�çÀ�Àƒà³ÀÃ`¸¸ƒ�WÁSà<°À48(¸üf{à‹çÁsà«àxŒƒÃàð×à1 ƒ»·mö\­D‰%›*k-?:X–l¼þèDÉÆi®‰)�¥P‹²ÿ_{“‚ŽuQzÅYÔWxõ¾ÍWx_Ú%žˆÌ�O�î([:V“C;”è#4ö$™Þmi˜ElC…ŠœÜÝ\½-Ò;ÍzÚm¨ƒmUØÕÃ&¢Y‘K\òÕz¬GªÙpÈµpk·µ[
 ¢¡TF—Ü—>'Ð’&n{sÒ“klìÒÃøöu†qÓk„µ2ÇG šv†‘‡‡itÄ"vU*	¶óñyŽfwÆUlIÖˆ6BmÒÕ�Äšô‘»ÌBq|¾4+å1�;’ÿz›£O&8#„§ÀÑÁ•œÐH™'›L.Ž«—kM]žœ-ÍÌÑòäÜT"Ä]qDkÓ¬mëÚZÅuÌmS¹kdnKOjÓMÖ
 Ñ­§ÛK¦ƒV[ûlMàÓoÈQ>pMSØÏ‘ 0·„uy@O¾’Q¼Í¬L"œ�%ÿPKÚh§
-PPK&�Ì(.DBSAXHandler.java.swpíœ{ŒUÇ§´….T@ñrºmÒ»íuî¶P»Ùp¡Ý®Ý-A`îÌ¹÷NwîÌÝ™sw÷*õ�ÑøCÐ�‰ÄˆT�A£FÔàMÀP5hx”@#bÄïyÍãÞ}µ‘d~áÓ»3sæÌïü~çù›3Tú//ï&;Ìs
+PPKÓ¥Í(.DBSAXHandler.java.swpíœ{ŒUÇ§´….T@ñrºmÒ»íuî¶P»Ùp¡Ý®Ý-A`îÌ¹÷NwîÌÝ™sw÷*õ�ÑøCÐ�‰ÄˆT�A£FÔàMÀP5hx”@#bÄïyÍãÞ}µ‘d~áÓ»3sæÌïü~çù›3Tú//ï&;Ìs
 Èé†qãŸ/8¿üqÃxàÃ8ø42–—:¥þ
 ’–šap€ÚTÜ’Cg©4Ôg¥ù†Ç§RŠB»D�V©eG•’oS+*5(³l‹•F‡'‡ö_bùŽGCó€5k­ä¹¹ä’‹”s¶oëßØ»�œñ¦}¯µ*¹ä’K.¹ä’K.¹ä’ËÿXXs�ñ2~OC`•b
 xVÇkÁà«ãÕàLpXç’K.¹ä’K.¹ä’K.¹ä’K.ÿ¿b9øç$Ãxû:C¼ÿç1€ŸfŸ.ØþtªaÜ~šÀÓà2p)8œX{ƒa<
@@ -507,8 +506,8 @@
 ñb!žÇ3fQiøÓG¹ÑâOYºÖ�Ù›ÄXÀÿâ©ËG²ôý(^&Ÿ�(
 T«ÎÆÌô§ÊÔC¥‹(}›ü6 ùp$ÎU­Jc×$Ù¨ûe‚îûá¤rÎÓ�štøa •szf!âNÚG<ÿÔ—	;É¶Ìw-Úoþ–½k3pù$Hu½â™ïŒº¿ÁYp„#I=LŸ>ˆ^Œa\),°wžÐ´Ò¹Ê¬–j³ÏËÞ�ª‹�É�á%2Û±š™^'ð±6Û,£¾ìœ¸�eÒdÓƒ
 >¹z`Œ=¹u«ÎL_Yáˆ¸?×ÉR]X¢uÒ—ëd©žO'›éHÒÑaÆÝø3œ'AwèÙ�ge¡:Nv56u~FžK|qÜ·„üPKoÓ%‹£
-`PK&�Ì(	notes.txt=N»Â0œéWÜÿ@Õ™……5JÜ6¢ØÈqTñ÷8íâóùqwCÿ¸=ï’,+,¼¨ `8¦*bÜšÀi_ë›Ø«ª£st§Pð	j�6¢p1­ÑD¯@_
-JaY¾öÂD	&þQÊ!Ú<\'%Ld›aqT©–Ùc�¢mádÚöh9á¼Î9ÎÈÅýÈU2·“ôOzéºîPKO›#—êPK&�Ì(.DBWriter.java.swpíš]lWÇ‡„´I¡%„¾ðÐp³I“upg×vÒuj{7‰Cl§v6
+`PKÓ¥Í(	notes.txt=N»Â0œéWÜÿ@Õ™……5JÜ6¢ØÈqTñ÷8íâóùqwCÿ¸=ï’,+,¼¨ `8¦*bÜšÀi_ë›Ø«ª£st§Pð	j�6¢p1­ÑD¯@_
+JaY¾öÂD	&þQÊ!Ú<\'%Ld›aqT©–Ùc�¢mádÚöh9á¼Î9ÎÈÅýÈU2·“ôOzéºîPKO›#—êPKÓ¥Í(.DBWriter.java.swpíš]lWÇ‡„´I¡%„¾ðÐp³I“upg×vÒuj{7‰Cl§v6
 M,4;s½;ÎìÜeæ®c‚ñ@ÊC+@T< ñ$D)B‚>�T�PxA  ”ï–‰§òBTþçÎç~ØI
 ¢ æH¿Ý�™sÏý:÷ãÜÙZñÔÔ4Û§?¨A¶jÚ�eå¡ù�kÚ´®iKÂå¾vsipîÞ‚šö1e°ÐòÄ7%~Ôì‚Å—¹#ZMîÊÂJÓ‘Âª|Ï,p«]h›~­àšÜðM.
 Ó�…òÄ£ž-¹§/ËÆ­ä™I&™$22<TÜ™ÛÁÞµ­úf%“L2É$“L2É$“L2ù‹lmÐ^Ç÷@±þ[B6‚Sô<¼Î$“L2É$“L2É$“L2É$“LþwÅ°4m3¾_¡ kpð�whÚKà*ø ¸üäM{|`œÁ(¸ìÛÀ�»5ígàûàkà«@€÷ƒÍào×´çÀwÁgÀ§Á“à,Ø	Þîw€gÞ¦iO�'Áe0Ž�Í`#xá.M»‚¿mÑ´¿€çÁwÀUð9pì/£¢×Àà[à*¸ª îwƒëwjÚ‹àÛàiðIðxl×ïÐ´ï�çÁgÁaP÷ƒW6¡^àSààqðQ°
@@ -532,7 +531,7 @@
 v1¸â`/ŸÎû§½mÏl§�0—	ÚX'íÚM=ì°iE§ÁÝÃˆ˜¤¿ì(VSga—Q„Hs×²M§µÕ¨$I±Žc‘Œ…‡œ©®Mð3ÖÙk¬§c]Þa¤·WXGçÆFÐæ}K�† GÄA
 žŽ×ìíªÇwç�´ Ednw°«l$“g¡ ¥¨ÝŠƒæ8ÖiDNEæÈ0pÓIû¼U‰NS¢…-QéyßÒý–BKë]ñú-­‹žhÆaW‰Õ~/Ënò®ì–øoþ¦ì
 ™ê÷žŒöû’“Ñµ_—‘âƒ]ŠÉ[3z:’<í~y¦Ö€@kxÝÌ¢÷h¤9”hÞÆë4JYì³rÓZ”¼³RkM0X’ùè2~E1Ð§“ÿ+_ÐýPK/§yGË
-@PK&�Ì(DBSimpleQuery.java.new�X[oÛ6~®Å©1`rjÈqº>ÔNÒ¥‰ÚfË¥�›m@[ŒDÇjeQ#)'Æ�ÿ¾Ã‹$ÒR“tZGä¹óã9Ÿ=ÚÚêÁØçŒ,éŽ^ÏÒe‘Ñ%åëð+Y‘Jä}É&Pä3"È‘ (áñ‚
+@PKÓ¥Í(DBSimpleQuery.java.new�X[oÛ6~®Å©1`rjÈqº>ÔNÒ¥‰ÚfË¥�›m@[ŒDÇjeQ#)'Æ�ÿ¾Ã‹$ÒR“tZGä¹óã9Ÿ=ÚÚêÁØçŒ,éŽ^ÏÒe‘Ñ%åëð+Y‘Jä}É&Pä3"È‘ (áñ‚
  ÀiFdÊr’¡˜34£KšKÜÌp\™‡HÉÓ«RRkjAVæœR�ôVÂ’HmX2Ü¦ð�
 ªä×!´­K@–<7¡ˆ2SÁIˆY.R!QØ\[âŒIÈYBÓDGÙ2EI¼€„Å¥
 Þ¦‰™‰yªCµ±µCV¬yz½�ØÙÞÞ†z­3¶¾.ótE¹HåZ­’,E�yJtEP åû¬*á!š¡\Å,c×iŒ«¸µÆ|´þl�£	|«¬”rÁ¸˜À)Ö~c9U[Õî*–OàçŸŽ“®“®`¾ÔyŒ¶_ŒÆÏa{<Ùy9y1†¯ÊD·üô3Úõz‰¿‘k
@@ -548,7 +547,7 @@
 _1–Qìa¦ˆ×Õ�p=ý\I;T]A€TxD]ô¦&i0öÚ~L#b“ÛÙ²õ„ž·„,P=©_üÉèbõ^rS	6ãö‘ÜŸ‚ŠƒWI>5÷£ƒj´=)…}„X]¡g`<˜�ïrëO×ëGü)…ÊŸV®ü™�ýéÒÿ�C¥Q{ÔêµK³µáÓçµ3‰ôm³V?Ì5·é�6�¦!‡E)…
 Ks˜CÛÔuÈ’Y
 ZÔú YU#^ùT—)Z¬¾±Ùßâ’3Oìóð•ºÛ¸ÌqÆ„s•kÎæŽ`Ÿ¶up¿~Ä92¼š¥¤ÉDu/ø³¥6_‰ýš™	}×ûPK?
-W�„}PK&�Ì(.DBSimpleQuery.java.swpíš_lGÇ§Iiþ—*}‰D+&G¥žÍiÏvbD.ŽSÿ¹&Ný/vœ %ÚÛ�óm²·»Ù�µ}
+W�„}PKÓ¥Í(.DBSimpleQuery.java.swpíš_lGÇ§Iiþ—*}‰D+&G¥žÍiÏvbD.ŽSÿ¹&Ný/vœ %ÚÛ�óm²·»Ù�µ}
 i�@©*ÑÒ­Ry¡<ä¡�‡òO< ¾B<µATAðB%Pá;3»{»wgÇ)‚ÚŸòÉyg~óÿ7³3¿�ÚÀÙ©:¬&�9ò™ê‘ÙOò+\t�ÛKƒ1gjäI™aÙóÝ‹Ìàø£f•M¶Êl×k2‡—×›6wÍZ9ð�23Ãrhµ²c0=(7×
 �—'Ç­¦g³Ó!ó[ÚE}UßJÁ¹ä’‹”CCƒ)¤î_ºÛUÉ%—\rÉ%—\rÉ%—\þÃÂ½íäøÝæÁ=÷‚`!zÞN�FôœK.¹ä’K.¹ä’K.¹ä’K.¹üïˆnr‡ûo‰ÿÊð÷òKð0Þ½Ÿ�7À§ÀÇÀ‡Àð“}„üü¼^Ï‚+à}`øÓ^Bn�?€¯‚³`7¸O„í!ä&ø:x
 <	ÖAƒ?ï&äðXÀOwòcðx\|¼·“�×Á«à+àÐg@ì7wò6øx<<`½��kà*8>Þþ!o�ëà³€�“`?¸y¯êGÌ€‡ÀMôíóàÀ€	FÁ1ð0øÍ6B¾žO�uÀÁep	eðÛ{ù6 ”öSÝ¡–pÝ1å.
@@ -572,7 +571,7 @@
 W|^µÖLš«Z™˜QâêØ•]¶£Ù™D+“Œ¼Ií�	ÙÏi¿ooÿäfÞ<©¨´c·Z;>åæërôˆ.�>OW�²ã–ÎŸÔ—GÞ°-r³‰Ñ¤¬£=#ò>ëòÇÝÐ1“7íÆúé÷q‰öÐã
 _,
 SsYµ¨W³ßTÒ_(d•ûh�þ”1¢oNMŽOd¾F¿ÁË¸Z“9¯ÎÿÎØ7€8ÿ‹;ÿoâŒÿ5à‚£à=œãßß__pÁØ/ü8¿_¯�WÁ7¢;/‚:ÐÁƒû¢rrÉ%—\rÉ%—\rÉ%—\þ-Bó³íƒéÿÕ�ÙÎ›—Y?hV
-âžì¦·bosÇ¶ë–m&ñÝ¼RY`ÖG›º×B£$Â“×ék!ÉQJþ	PKós0·PPK&�Ì(.DBSAXDocument.java.swpíš[ŒG†Ë×Ø±v‰+‹ag7»3»›ÅkYfwfŒÇÚ[vÆ7�0=Ýµ;m÷t�»ª÷
+âžì¦·bosÇ¶ë–m&ñÝ¼RY`ÖG›º×B£$Â“×ék!ÉQJþ	PKós0·PPKÓ¥Í(.DBSAXDocument.java.swpíš[ŒG†Ë×Ø±v‰+‹ag7»3»›ÅkYfwfŒÇÚ[vÆ7�0=Ýµ;m÷t�»ª÷
  ,�°p,?",ñ€�	D (ñD€ð‘añD!ˆA�¿ªºgºç²0	ˆ>òç�éª®:uêTu�ÓS9]š¦‡²È>B¾|­xøÄeBÎŒrÁs'ëK�1wÕÈGUƒ¹†ï]`¦À‡ª�³Øs¼F�¹"·Rw„gUsÜ7sÌ
 r�É«9×dÏÕ™0LCä
 “å‰³Ïä
@@ -597,7 +596,7 @@
 üqÿÁ“à	ð(ÀÁQ°ìÛÀVpk/!Ï€«à“à,8€W÷è<Ásà:¨‚‡À]à'w"—@ÜÞ^ØMÈg@ÜÚEÈ×Á‡Á2˜o¿¹ƒ�oƒOƒs`¼Œ¸ÿ·à%ðð8hTÀ»À+;ùx<®€à^ð*ìü"øùvmó_� önÝÒ@©ü_ˆ>}·"juFðT‘�ÁÌÚ¥êQ‹~:³JªöîÛÔÎ¿ÕÌíK(ë¤>6—!ÛPŽl�Ð»-#"5mf9Âhù5Ês4ÖItt$	:Ê¢È}¬gä~Û"ü(ÆJH_~vfF¦_&ÏÑ¹ùÒì<mFŽ2Œv£žºÅý¸»\™@ô~¦T9ÑºïX×H•Ïœ(ÎU½0xíWs×ß«~&Ì…-«�ÌÈïíù�æM3…„æ´4³¾>a¨Ý_)ž­ôT'¦�:M®©Ï:ùŠÜ`¬.f.àrÝè˜m˜7˜i/àè[³qúôÍš:jéYLÜ%'×ôê²I¼Bå'ÔùH‡<\†XËê˜„à§mG’º´ÔŒOÄ»|XV¤Ç:c%ŒcÂHQiår¡ÃÃm*©ÕˆC˜Ay]=<¨
 Ÿ1Z…vˆ4
 ™láJs„Šh¡.OjøÉ†PëŠÓ‰©©èÄ¨Û#D.ÂWÎ”º°ž<šz.K6S‘ÉÞª·®Z—Rqr˜gH�5¥Ë*]¶¡/ŠªÌ4Î:sbp‚ÙùBq^.í]=–Î×pÃDæížkÖŽù!í‡«Mgzû"¥›]L”þ§—S—!ÿ÷-¼¨ZüÃ’†Ý²ÄQYGÏ!™¨J¼‘PéÅèÑ{Ü÷êy8®UtÂ4u¤F3¦œÒg¦J,aÅðDæ!|2‡U§bï4´áZY°}.¨){JäT,Ú§êõ©d¤>D�Ô5ßƒýë/¼z<Ê{æÐ»eÐÛîŠ=8Uª££ÙVê|t¨™êHö±™Œxè´Ñ«—c�+¿�–‹•fO=ü¿ïÔ\a¢R\#×½A^ÇeãþÝL(‡zÅ“>]\4“ôè.f½tyâÄ¨6á.‰²èNyrêáÍ¾Øz—Û©p¨áb¤r%ß·¡®þ	PK�"n•
-@PK&�Ì(.DBSAXNode.java.swpíšklWÇoã”4¥i¢ñTÝl«vm–]ÛÍCqdÒõîVYc;©w�¶B"ÌÎ\{Ç™�ÙÌÜñ#U*AÅ‡ð!©<‚"µRZµ*�*‰"Bð
+@PKÓ¥Í(.DBSAXNode.java.swpíšklWÇoã”4¥i¢ñTÝl«vm–]ÛÍCqdÒõîVYc;©w�¶B"ÌÎ\{Ç™�ÙÌÜñ#U*AÅ‡ð!©<‚"µRZµ*�*‰"Bð
 _€"ÑŠJUÅ¨(ÿ{ï<w×Î£�¶0GùeggÎ}ž3÷Þs¼­ÑãõYº¯¸—@v²û\íàô“„<}��eÇf¹º´³¯A�<!+,u]g™é-³d°f9Ý³yi­cqÇh•<W/1Ã/ùº×*Ù:Ó¼R‡qM×x©:Õ(?:ç¬¸¬­h×Òh&™dÉãc£÷äöÐÝµðnw%“L2É$“L2É$“L2¹ÉÂ»[ÈÛøÜN‚[†@ØÁ÷L2É$“L2É$“L2É$“L2Éäý+šAÈ9|ÎŠÀ.•xk'!¿_
 °¼q'!¯ƒo‚o€¯ƒÓ`,‚iP»ÀNp;øåB¾
 Î�Ð@
@@ -623,15 +622,15 @@
 ÇáDî´{Âh¡'¼´[—›ÍùúÔB³†í‹ØœÜ®qq\„lÉ`®Œ…A­`bíÑ¢˜j×w’ðÄ'7t"F}ÍoZ}mãªÛØ¨Ü ¤ºB‚ªD+�}ABªáàœµWÝ�¥ÅÖU6Œ`ÛŽ;!ƒÖàôW X¼Qµ\!eP+öËeÜwmª§¥¦‘¢º«Nh¢^Eß;-æö‡Â�ÍŸ÷¦�p“I#;˜Èm�»jÊ�3J‡ã‰Qà¬æz¢)™„ëÉ:HÛ`ŸwV½d-Ç±6—äsU“�“K²Ùyæùo`f]¡!û&’"áí¤n*¯•kà�[iÆA-:{Âc§Š"V€…èCóGg©ákV®§Š0ÖUGù8Ô�Ô’±jÌÆ±,¥–#¼(ž¥ÉQyp
 Žqòé€£säm–ãœ¤~W9} œ
 ºè:�þ 4áj›zË�»ÅÀ\â†ÙÄÍò‰½©«ñ�siµ1™·Ál¦Ù4—DS’{äHm¾F“y!ûpo
-ŠÇªåf-‘ï¶Ì‰×Ÿ‘=<ÝétÂC1=V§Žzí¹Ó%éßo3=xªoò$ošbŠ_Ü¾¤‘J~È÷2x:d�øQúòFÐëúrbW&¾ªDEt’NøB	n ÆïÛ¶º”2	¢Àÿ‹×;LÑ¾;ž'ˆo¶û%²-Ò“óðQToÝ‘ôæþ'},ý‰Ô-nž‹E¼É6´›ïI¿SïŠÆ³�gýPK$êG®Ò	@PK&�Ì(	META-INF/PK&�Ì(©RfÍ9META-INF/MANIFEST.MFPK&�Ì(”edu/PK&�Ì(	Èedu/ucsb/PK&�Ì(edu/ucsb/nceas/PK&�Ì(@edu/ucsb/nceas/metacat/PK&�Ì(°‰^")‡edu/ucsb/nceas/metacat/BasicElement.classPK&�Ì(¤…£2@)edu/ucsb/nceas/metacat/DBDTDHandler.classPK&�Ì(Âwÿ‹üt
--‰	edu/ucsb/nceas/metacat/DBEntityResolver.classPK&�Ì(·V¦/!	ª%àedu/ucsb/nceas/metacat/DBReader.classPK&�Ì(ß>ËX1Tedu/ucsb/nceas/metacat/DBReader$DoctypeInfo.classPK&�Ì(õ<e3R*~edu/ucsb/nceas/metacat/DBSAXDocument.classPK&�Ì(]Éî�†)	#edu/ucsb/nceas/metacat/DBSAXElement.classPK&�Ì(<–ö¦‡)æ)edu/ucsb/nceas/metacat/DBSAXHandler.classPK&�Ì(Ú]K”Æç(ã2edu/ucsb/nceas/metacat/DBSAXWriter.classPK&�Ì()s´´}*ÿ:edu/ucsb/nceas/metacat/DBSimpleQuery.classPK&�Ì(¼Ûó(_Cedu/ucsb/nceas/metacat/DBTransform.classPK&�Ì(›XÍ‰gß/¨Ledu/ucsb/nceas/metacat/GenericXMLValidate.classPK&�Ì(°#t‘
-;lTedu/ucsb/nceas/metacat/GenericXMLValidate$ErrorStorer.classPK&�Ì(`qQŠ0¡:ØXedu/ucsb/nceas/metacat/GenericXMLValidate$ParseError.classPK&�Ì(N”÷OÀ
-++p[edu/ucsb/nceas/metacat/MetaCatServlet.classPK&�Ì(ÎRîÚ Â(‰qedu/ucsb/nceas/metacat/MetaCatUtil.classPK&�Ì(Pµ%ö‚*ÿsedu/ucsb/nceas/metacat/ReaderElement.classPK&�Ì(+v¨{(M|edu/ucsb/nceas/metacat/XMLValidate.classPK&�Ì(��´Û:Ï)Kedu/ucsb/nceas/metacat/metacat.propertiesPK&�Ì(�F¶ «ù%Ü€edu/ucsb/nceas/metacat/TextNode.classPK&�Ì(êæoO–R&Ú‚edu/ucsb/nceas/metacat/BasicNode.classPK&�Ì(qô˜³(Äˆedu/ucsb/nceas/metacat/ElementNode.classPK&�Ì(0o=GÒ£&²‘edu/ucsb/nceas/metacat/DBSAXNode.classPK&�Ì(ã²Ÿ*Ž%Ø™edu/ucsb/nceas/metacat/DBWriter.classPK&�Ì(ßÂIâÖ!,U¢edu/ucsb/nceas/metacat/AccessionNumber.classPK&�Ì(à_ö´W
-P…ª.ReaderElement.java.swpPK&�Ì(ÿëüõç@!µ.BasicElement.java.swpPK&�Ì(Óíe‘ú0L¾.TextNode.java.swpPK&�Ì(Ñ=½Ug`†Â.ElementNode.java.swpPK&�Ì(‚�Bô¡
-`0Î.DBReader.java.swpPK&�Ì(Úh§
-PÜ.DBSAXElement.java.swpPK&�Ì(oÓ%‹£
-`]æ.DBSAXHandler.java.swpPK&�Ì(O›#—ê	Dônotes.txtPK&�Ì(/§yGË
-@õ.DBWriter.java.swpPK&�Ì(?
-W�„}DBSimpleQuery.java.newPK&�Ì(ós0·På.DBSimpleQuery.java.swpPK&�Ì(�"n•
-@-.DBSAXDocument.java.swpPK&�Ì($êG®Ò	@.DBSAXNode.java.swpPK,,c
-(
\ No newline at end of file
+ŠÇªåf-‘ï¶Ì‰×Ÿ‘=<ÝétÂC1=V§Žzí¹Ó%éßo3=xªoò$ošbŠ_Ü¾¤‘J~È÷2x:d�øQúòFÐëúrbW&¾ªDEt’NøB	n ÆïÛ¶º”2	¢Àÿ‹×;LÑ¾;ž'ˆo¶û%²-Ò“óðQToÝ‘ôæþ'},ý‰Ô-nž‹E¼É6´›ïI¿SïŠÆ³�gýPK$êG®Ò	@PKÓ¥Í(	META-INF/PKÓ¥Í(©RfÍ9META-INF/MANIFEST.MFPKÓ¥Í(”edu/PKÓ¥Í(	Èedu/ucsb/PKÓ¥Í(edu/ucsb/nceas/PKÓ¥Í(@edu/ucsb/nceas/metacat/PKÓ¥Í(°‰^")‡edu/ucsb/nceas/metacat/BasicElement.classPKÓ¥Í(¤…£2@)edu/ucsb/nceas/metacat/DBDTDHandler.classPKÓ¥Í(MT`œÍ
+-‰	edu/ucsb/nceas/metacat/DBEntityResolver.classPKÓ¥Í(·V¦/!	ª%ùedu/ucsb/nceas/metacat/DBReader.classPKÓ¥Í(ß>ËX1medu/ucsb/nceas/metacat/DBReader$DoctypeInfo.classPKÓ¥Í(·Þi7ÙÄ
+*—edu/ucsb/nceas/metacat/DBSAXDocument.classPKÓ¥Í(]Éî�†)È"edu/ucsb/nceas/metacat/DBSAXElement.classPKÓ¥Í(<–ö¦‡)¥)edu/ucsb/nceas/metacat/DBSAXHandler.classPKÓ¥Í(Ú]K”Æç(¢2edu/ucsb/nceas/metacat/DBSAXWriter.classPKÓ¥Í(kEÍûÂc*¾:edu/ucsb/nceas/metacat/DBSimpleQuery.classPKÓ¥Í(¼Ûó(ØCedu/ucsb/nceas/metacat/DBTransform.classPKÓ¥Í(›XÍ‰gß/!Medu/ucsb/nceas/metacat/GenericXMLValidate.classPKÓ¥Í(°#t‘
+;åTedu/ucsb/nceas/metacat/GenericXMLValidate$ErrorStorer.classPKÓ¥Í(`qQŠ0¡:QYedu/ucsb/nceas/metacat/GenericXMLValidate$ParseError.classPKÓ¥Í(J™öw»++é[edu/ucsb/nceas/metacat/MetaCatServlet.classPKÓ¥Í(ÎRîÚ Â(Xredu/ucsb/nceas/metacat/MetaCatUtil.classPKÓ¥Í(Pµ%ö‚*Îtedu/ucsb/nceas/metacat/ReaderElement.classPKÓ¥Í(+v¨{(}edu/ucsb/nceas/metacat/XMLValidate.classPKÓ¥Í(��´Û:Ï)€edu/ucsb/nceas/metacat/metacat.propertiesPKÓ¥Í(�F¶ «ù%«�edu/ucsb/nceas/metacat/TextNode.classPKÓ¥Í(êæoO–R&©ƒedu/ucsb/nceas/metacat/BasicNode.classPKÓ¥Í(qô˜³(“‰edu/ucsb/nceas/metacat/ElementNode.classPKÓ¥Í(0o=GÒ£&�’edu/ucsb/nceas/metacat/DBSAXNode.classPKÓ¥Í(ã²Ÿ*Ž%§šedu/ucsb/nceas/metacat/DBWriter.classPKÓ¥Í(ßÂIâÖ!,$£edu/ucsb/nceas/metacat/AccessionNumber.classPKÓ¥Í(à_ö´W
+PT«.ReaderElement.java.swpPKÓ¥Í(ÿëüõç@ðµ.BasicElement.java.swpPKÓ¥Í(Óíe‘ú0¿.TextNode.java.swpPKÓ¥Í(Ñ=½Ug`UÃ.ElementNode.java.swpPKÓ¥Í(‚�Bô¡
+`ÿÎ.DBReader.java.swpPKÓ¥Í(Úh§
+PàÜ.DBSAXElement.java.swpPKÓ¥Í(oÓ%‹£
+`,ç.DBSAXHandler.java.swpPKÓ¥Í(O›#—ê	õnotes.txtPKÓ¥Í(/§yGË
+@áõ.DBWriter.java.swpPKÓ¥Í(?
+W�„}ìDBSimpleQuery.java.newPKÓ¥Í(ós0·P´.DBSimpleQuery.java.swpPKÓ¥Í(�"n•
+@ü.DBSAXDocument.java.swpPKÓ¥Í($êG®Ò	@Ö.DBSAXNode.java.swpPK,,c
+é(
\ No newline at end of file
Index: src/edu/ucsb/nceas/metacat/DBSimpleQuery.java
===================================================================
--- src/edu/ucsb/nceas/metacat/DBSimpleQuery.java	(revision 153)
+++ src/edu/ucsb/nceas/metacat/DBSimpleQuery.java	(revision 154)
@@ -43,24 +43,25 @@
    */
   static public void main(String[] args) {
      
-     if (args.length < 3)
+     if (args.length < 4)
      {
         System.err.println("Wrong number of arguments!!!");
         System.err.println("USAGE: java DBSimpleQuery " +
-                           "<query> <user> <password> [dbstring]");
+                           "<query> <doctype> <user> <password> [dbstring]");
         return;
      } else {
         try {
                     
           String query    = args[0];
-          String user     = args[1];
-          String password = args[2];
+          String doctype  = args[1];
+          String user     = args[2];
+          String password = args[3];
           String dbstring = null;
 
-          if (args.length <= 3) {
+          if (args.length <= 4) {
             dbstring = defaultDB;
           } else {
-            dbstring = args[3];
+            dbstring = args[4];
           }
 
           // Open a connection to the database
@@ -69,7 +70,12 @@
                               dbstring, user, password);
           // Execute the simple query
           DBSimpleQuery rd = new DBSimpleQuery(dbconn);
-          Hashtable nodelist = rd.findDocuments(query);
+          Hashtable nodelist = null;
+          if (doctype.equals("any") || doctype.equals("ANY")) {
+            nodelist = rd.findDocuments(query);
+          } else {
+            nodelist = rd.findDocuments(query, doctype);
+          }
 
           // Print the reulting root nodes
           StringBuffer result = new StringBuffer();
@@ -119,6 +125,16 @@
    * @param query the text to search for
    */
   public Hashtable findDocuments(String query) {
+    return this.findDocuments(query, null);
+  }
+
+  /** 
+   * routine to search the elements and attributes looking to match query
+   *
+   * @param query the text to search for
+   * @param requestedDoctype the type of documents to return from the query
+   */
+  public Hashtable findDocuments(String query, String requestedDoctype) {
       Hashtable	 docListResult = new Hashtable();
 
       PreparedStatement pstmt;
@@ -131,16 +147,32 @@
       StringBuffer document = null; 
 
       try {
-        pstmt =
-          conn.prepareStatement(
+        if (requestedDoctype == null || 
+            requestedDoctype.equals("any") || 
+            requestedDoctype.equals("ANY")) {
+          pstmt = conn.prepareStatement(
                 "SELECT docid,docname,doctype,doctitle " +
                 "FROM xml_documents " +
                 "WHERE docid IN " +
                 "(SELECT docid " +
                 "FROM xml_nodes WHERE nodedata LIKE ? )");
-        // Bind the values to the query
-        pstmt.setString(1, query);
 
+                // Bind the values to the query
+                pstmt.setString(1, query);
+        } else {
+          pstmt = conn.prepareStatement(
+                "SELECT docid,docname,doctype,doctitle " +
+                "FROM xml_documents " +
+                "WHERE docid IN " +
+                "(SELECT docid " +
+                "FROM xml_nodes WHERE nodedata LIKE ? ) " +
+                "AND doctype = ?");
+
+                // Bind the values to the query
+                pstmt.setString(1, query);
+                pstmt.setString(2, requestedDoctype);
+        }
+
         pstmt.execute();
         ResultSet rs = pstmt.getResultSet();
         boolean tableHasRows = rs.next();
Index: bin/queryxml
===================================================================
--- bin/queryxml	(revision 153)
+++ bin/queryxml	(revision 154)
@@ -4,4 +4,4 @@
 export PW=your-pw-goes-here
 export DBC=jdbc:oracle:thin:@localhost:1521:test
 
-java -cp ${CPATH} edu.ucsb.nceas.metacat.DBSimpleQuery $1 $USER $PW $DBC
+java -cp ${CPATH} edu.ucsb.nceas.metacat.DBSimpleQuery $1 $2 $USER $PW $DBC

Index: src/edu/ucsb/nceas/metacat/MetaCatServlet.java
===================================================================
--- src/edu/ucsb/nceas/metacat/MetaCatServlet.java	(revision 153)
+++ src/edu/ucsb/nceas/metacat/MetaCatServlet.java	(revision 154)
@@ -1,11 +1,11 @@
 /**
- *        Name: MetaCatServlet.java
- *     Purpose: A Class that implements a metadata catalog as a java Servlet
- *   Copyright: 2000 Regents of the University of California and the
- *              National Center for Ecological Analysis and Synthesis
- *     Authors: Matt Jones, Dan Higgins
- * 
- *     Version: '$Id$'
+ *      Name: MetaCatServlet.java
+ *   Purpose: A Class that implements a metadata catalog as a java Servlet
+ * Copyright: 2000 Regents of the University of California and the
+ *            National Center for Ecological Analysis and Synthesis
+ *   Authors: Matt Jones, Dan Higgins
+ *
+ *   Version: '$Id$'
  */
 
 package edu.ucsb.nceas.metacat;
@@ -39,28 +39,29 @@
 import oracle.xml.parser.v2.XSLException;
 import oracle.xml.parser.v2.XMLDocumentFragment;
 import oracle.xml.parser.v2.XSLProcessor;
-import oracle.xml.parser.v2.*;    //Oracle parser - DFH
-import java.io.File;  //DFH
-import java.io.FileInputStream; //DFH
+import oracle.xml.parser.v2.*;    
+import java.io.File;
+import java.io.FileInputStream;
 
 /**
  * A metadata catalog server implemented as a Java Servlet
    *
    * <p>Valid parameters are:<br>
    * action=query -- query the values of all elements and attributes
    *                     and return a result set of nodes<br>
    * action=getdocument -- display an XML document in XML or HTML<br>
    * qformat=xml -- display resultset from query in XML<br>
    * qformat=html -- display resultset from query in HTML<br>
    * action=getdocument -- display an XML document in XML or HTML<br>
    * docid=34 -- display the document with the document ID number 34<br>
    * action=putdocument -- load an XML document into the database store<br>
    * doctext -- XML text ofthe document to load into the database<br>
    * query -- actual query text (to go with 'action=query')<br>
    * action=validate -- vallidate the xml contained in validatetext<br>
    * valtext -- XML text to be validated
    * action=getdatadoc -- retreive a stored datadocument  //DFH
    * datadoc -- data document name (id)                   //DFH
  */
 public class MetaCatServlet extends HttpServlet {
 
@@ -75,8 +76,10 @@
   String 	defaultDB = null;
   String 	resultStyleURL = null;
   String 	xmlcatalogfile = null;
-  String    defaultdatapath = null;  // path to directory where data files that can be downloaded will be stored
-  String    executescript  = null;  // script to get data file and put it in defaultdocpath dir
+  String    defaultdatapath = null; // path to directory where data files 
+                                    // that can be downloaded will be stored
+  String    executescript  = null;  // script to get data file and put it 
+                                    // in defaultdocpath dir
   PropertyResourceBundle options = null;
 
   /**
@@ -90,7 +93,8 @@
       System.out.println("Servlet Initialize");
 
       // Get the configuration file information
-      options = (PropertyResourceBundle)PropertyResourceBundle.getBundle("edu.ucsb.nceas.metacat.metacat");
+      options = (PropertyResourceBundle)
+          PropertyResourceBundle.getBundle("edu.ucsb.nceas.metacat.metacat");
       user = (String)options.handleGetObject("user");
       password = (String)options.handleGetObject("password");
       defaultDB = (String)options.handleGetObject("defaultDB");
@@ -239,8 +243,17 @@
       // Run the query
       Hashtable nodelist = null;
       String query = ((String[])params.get("query"))[0]; 
+      String[] doctypeArr = (String[])params.get("doctype");
+      String doctype = null;
+      if (doctypeArr != null) {
+        doctype = ((String[])params.get("doctype"))[0]; 
+      }
       if (queryobj != null) {
-        nodelist = queryobj.findDocuments(query);
+        if (doctype != null) {
+          nodelist = queryobj.findDocuments(query,doctype);
+        } else {
+          nodelist = queryobj.findDocuments(query);
+        }
       } else {
         out.println("Query Object Init failed.");
 	/*
@@ -361,7 +374,7 @@
   
   /** 
    * Handle the validtion request and return the results 
-   * to the requestor - DFH
+   * to the requestor
    */
   private void handleValidateAction(PrintWriter out, Hashtable params, HttpServletResponse response) {
 
@@ -463,7 +476,7 @@
     
   /** 
    * Handle the document request and return the results 
-   * to the requestor - DFH
+   * to the requestor
    */
   private void handleGetDataDocumentAction(PrintWriter out, Hashtable params, HttpServletResponse response) {
       boolean error_flag = false;
@@ -39,28 +39,29 @@
 /**
  * A metadata catalog server implemented as a Java Servlet
-   *
-   * <p>Valid parameters are:<br>
-   * action=query -- query the values of all elements and attributes
-   *                     and return a result set of nodes<br>
-   * action=getdocument -- display an XML document in XML or HTML<br>
-   * qformat=xml -- display resultset from query in XML<br>
-   * qformat=html -- display resultset from query in HTML<br>
-   * action=getdocument -- display an XML document in XML or HTML<br>
-   * docid=34 -- display the document with the document ID number 34<br>
-   * action=putdocument -- load an XML document into the database store<br>
-   * doctext -- XML text ofthe document to load into the database<br>
-   * query -- actual query text (to go with 'action=query')<br>
-   * action=validate -- vallidate the xml contained in validatetext<br>
-   * valtext -- XML text to be validated
-   * action=getdatadoc -- retreive a stored datadocument  //DFH
-   * datadoc -- data document name (id)                   //DFH
+ *
+ * <p>Valid parameters are:<br>
+ * action=query -- query the values of all elements and attributes
+ *                     and return a result set of nodes<br>
+ * action=query -- search text values for document match<br>
+ * doctype -- document type list returned by the query (publicID)
+ * qformat=xml -- display resultset from query in XML<br>
+ * qformat=html -- display resultset from query in HTML<br>
+ * action=getdocument -- display an XML document in XML or HTML<br>
+ * docid=34 -- display the document with the document ID number 34<br>
+ * action=putdocument -- load an XML document into the database store<br>
+ * doctext -- XML text ofthe document to load into the database<br>
+ * query -- actual query text (to go with 'action=query')<br>
+ * action=validate -- vallidate the xml contained in validatetext<br>
+ * valtext -- XML text to be validated
+ * action=getdatadoc -- retreive a stored datadocument
+ * datadoc -- data document name (id)
  */
 public class MetaCatServlet extends HttpServlet {